@@ -10,40 +10,40 @@
 // The program itself only initializes a USRP. For more elaborate examples,
 // have a look at the files in host/examples/.
 
-#include <uhd/utils/thread.hpp>
-#include <uhd/utils/safe_main.hpp>
 #include <uhd/usrp/multi_usrp.hpp>
-#include <boost/program_options.hpp>
+#include <uhd/utils/safe_main.hpp>
+#include <uhd/utils/thread.hpp>
 #include <boost/format.hpp>
+#include <boost/program_options.hpp>
 #include <iostream>
 
 namespace po = boost::program_options;
 
-int UHD_SAFE_MAIN(int argc, char *argv[]){
-    uhd::set_thread_priority_safe();
-
-    //variables to be set by po
+int UHD_SAFE_MAIN(int argc, char* argv[])
+{
+    // variables to be set by po
     std::string args;
 
-    //setup the program options
+    // setup the program options
     po::options_description desc("Allowed options");
-    desc.add_options()
-        ("help", "help message")
-        ("args", po::value<std::string>(&args)->default_value(""), "multi uhd device address args")
-    ;
+    desc.add_options()("help", "help message")("args",
+        po::value<std::string>(&args)->default_value(""),
+        "multi uhd device address args");
     po::variables_map vm;
     po::store(po::parse_command_line(argc, argv, desc), vm);
     po::notify(vm);
 
-    //print the help message
-    if (vm.count("help")){
-        std::cout << boost::format("Mini-example to initialize a USRP (args==%s).") % args << std::endl;
+    // print the help message
+    if (vm.count("help")) {
+        std::cout << boost::format("Mini-example to initialize a USRP (args==%s).") % args
+                  << std::endl;
         return ~0;
     }
 
-    //create a usrp device
+    // create a usrp device
     std::cout << std::endl;
-    std::cout << boost::format("Creating the usrp device with: %s...") % args << std::endl;
+    std::cout << boost::format("Creating the usrp device with: %s...") % args
+              << std::endl;
     uhd::usrp::multi_usrp::sptr usrp = uhd::usrp::multi_usrp::make(args);
 
     return EXIT_SUCCESS;
