@@ -1,18 +1,8 @@
 /*
  * Copyright 2015 Ettus Research LLC
+ * Copyright 2018 Ettus Research, a National Instruments Company
  *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 #include <uhd.h>
@@ -57,7 +47,7 @@ int main(int argc, char* argv[]){
     double freq = 2e9;
     double rate = 1e6;
     double gain = 0;
-    char* device_args;
+    char* device_args = NULL;
     size_t channel = 0;
     uint64_t total_num_samps = 0;
     bool verbose = false;
@@ -102,13 +92,9 @@ int main(int argc, char* argv[]){
         }
     }
 
-    if(uhd_set_thread_priority(uhd_default_thread_priority, true)){
-        fprintf(stderr, "Unable to set thread priority. Continuing anyway.\n");
-    }
+    if (!device_args)
+        device_args = strdup("");
 
-    if (device_args == NULL){
-        device_args = "";
-    }
     // Create USRP
     uhd_usrp_handle usrp;
     fprintf(stderr, "Creating USRP with args \"%s\"...\n", device_args);
@@ -125,7 +111,7 @@ int main(int argc, char* argv[]){
     // Create TX metadata
     uhd_tx_metadata_handle md;
     EXECUTE_OR_GOTO(free_tx_streamer,
-        uhd_tx_metadata_make(&md, false, 0.0, 0.1, true, false)
+        uhd_tx_metadata_make(&md, false, 0, 0.1, true, false)
     )
 
     // Create other necessary structs
@@ -195,7 +181,7 @@ int main(int argc, char* argv[]){
         uhd_tx_streamer_max_num_samps(tx_streamer, &samps_per_buff)
     )
     fprintf(stderr, "Buffer size in samples: %zu\n", samps_per_buff);
-    buff = malloc(samps_per_buff * 2 * sizeof(float));
+    buff = calloc(sizeof(float), samps_per_buff * 2);
     buffs_ptr = (const void**)&buff;
     size_t i = 0;
     for(i = 0; i < (samps_per_buff*2); i+=2){
@@ -215,7 +201,7 @@ int main(int argc, char* argv[]){
         if (stop_signal_called) break;
         if (total_num_samps > 0 && num_acc_samps >= total_num_samps) break;
 
-        EXECUTE_OR_GOTO(free_tx_streamer,
+        EXECUTE_OR_GOTO(free_buff,
             uhd_tx_streamer_send(tx_streamer, buffs_ptr, samps_per_buff, &md, 0.1, &num_samps_sent)
         )
 
@@ -226,6 +212,9 @@ int main(int argc, char* argv[]){
         }
     }
 
+    free_buff:
+        free(buff);
+
     free_tx_streamer:
         if(verbose){
             fprintf(stderr, "Cleaning up TX streamer.\n");
@@ -249,9 +238,8 @@ int main(int argc, char* argv[]){
         uhd_usrp_free(&usrp);
 
     free_option_strings:
-        if(device_args != NULL){
+        if(device_args)
             free(device_args);
-        }
 
     fprintf(stderr, (return_code ? "Failure\n" : "Success\n"));
 
