@@ -1,42 +1,37 @@
 //
-// Copyright 2014-2015 Ettus Research LLC
+// Copyright 2014-2017 Ettus Research
+// Copyright 2018 Ettus Research, a National Instruments Company
+// Copyright 2019 Ettus Research, a National Instruments Brand
 //
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
 //
 
 #ifndef INCLUDED_UHD_IMAGE_LOADER_HPP
 #define INCLUDED_UHD_IMAGE_LOADER_HPP
 
-#include <string>
-
-#include <boost/function.hpp>
-
 #include <uhd/config.hpp>
 #include <uhd/types/device_addr.hpp>
+#include <uhd/utils/noncopyable.hpp>
+#include <boost/function.hpp>
+#include <string>
 
-namespace uhd{
-
-class UHD_API image_loader : boost::noncopyable{
+namespace uhd {
 
+class UHD_API image_loader : uhd::noncopyable
+{
 public:
-
-    typedef struct{
+    typedef struct
+    {
         uhd::device_addr_t args;
         bool load_firmware;
         bool load_fpga;
+        bool download;
         std::string firmware_path;
         std::string fpga_path;
+        std::string out_path;
+        std::string id;
+        std::vector<uint8_t> component;
+        uhd::dict<std::string, std::string> metadata;
     } image_loader_args_t;
 
     //! Signature of an image loading function
@@ -55,7 +50,7 @@ public:
      *    device and expect the default image(s) to be loaded, but the specific
      *    model of the device cannot be determined beyond a category.
      */
-    typedef boost::function<bool(const image_loader_args_t &)> loader_fcn_t;
+    typedef boost::function<bool(const image_loader_args_t&)> loader_fcn_t;
 
     //! Register an image loader
     /*!
@@ -63,17 +58,15 @@ public:
      * \param loader_fcn  the loader function for the given device
      * \param recovery_instructions instructions on how to restore a device
      */
-    static void register_image_loader(
-        const std::string &device_type,
-        const loader_fcn_t &loader_fcn,
-        const std::string &recovery_instructions
-    );
+    static void register_image_loader(const std::string& device_type,
+        const loader_fcn_t& loader_fcn,
+        const std::string& recovery_instructions);
 
     //! Load firmware and/or FPGA onto a device
     /*!
      * \param image_loader_args arguments to pass into image loading function
      */
-    static bool load(const image_loader_args_t &image_loader_args);
+    static bool load(const image_loader_args_t& image_loader_args);
 
     //! Get the instructions on how to recovery a particular device
     /*!
@@ -82,9 +75,9 @@ public:
      * \param device_type the "type=foo" value given in an --args option
      * \return recovery instructions
      */
-    static std::string get_recovery_instructions(const std::string &device_type);
+    static std::string get_recovery_instructions(const std::string& device_type);
 };
 
-}
+} // namespace uhd
 
 #endif /* INCLUDED_UHD_IMAGE_LOADER_HPP */
