@@ -1,6 +1,7 @@
 //
 // Copyright 2011,2014-2016 Ettus Research
 // Copyright 2018 Ettus Research, a National Instruments Company
+// Copyright 2019 Ettus Research, a National Instruments Brand
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 //
@@ -9,12 +10,13 @@
 #define INCLUDED_UHD_PROPERTY_TREE_HPP
 
 #include <uhd/config.hpp>
-#include <boost/utility.hpp>
-#include <boost/shared_ptr.hpp>
+#include <uhd/utils/noncopyable.hpp>
 #include <boost/function.hpp>
+#include <boost/shared_ptr.hpp>
+#include <boost/utility.hpp>
 #include <vector>
 
-namespace uhd{
+namespace uhd {
 
 /*!
  * A templated property interface for holding the state
@@ -33,8 +35,8 @@ namespace uhd{
  *    in a desired value and produces a coerced value.
  *    A property must have *exactly one* coercer.
  * 2. Manual coercion: Manually calling the set_coerced
- *    API fnction to coerce the value of the propery. In
- *    order to use manual coercion, the propery must be
+ *    API function to coerce the value of the property. In
+ *    order to use manual coercion, the property must be
  *    created with the MANUAL_COERCE mode.
  * If the coerce mode for a property is AUTO_COERCE then
  * it always has a coercer. If the set_coercer API is
@@ -52,7 +54,7 @@ namespace uhd{
  * callback to get the value of the property. Calling
  * get on the property will always call the publisher and
  * the cached desired and coerced values are updated only
- * using set* calls. A preprty must have *at most one*
+ * using set* calls. A property must have *at most one*
  * publisher. It is legal to have both a coercer
  * and publisher for a property but the only way to access
  * the desired and coerced values in that case would be by
@@ -63,11 +65,13 @@ namespace uhd{
  * - T must have a copy constructor
  * - T must have an assignment operator
  */
-template <typename T> class property : boost::noncopyable{
+template <typename T>
+class property : uhd::noncopyable
+{
 public:
-    typedef boost::function<void(const T &)> subscriber_type;
+    typedef boost::function<void(const T&)> subscriber_type;
     typedef boost::function<T(void)> publisher_type;
-    typedef boost::function<T(const T &)> coercer_type;
+    typedef boost::function<T(const T&)> coercer_type;
 
     virtual ~property<T>(void) = 0;
 
@@ -81,7 +85,7 @@ public:
      * \return a reference to this property for chaining
      * \throws uhd::assertion_error if called more than once
      */
-    virtual property<T> &set_coercer(const coercer_type &coercer) = 0;
+    virtual property<T>& set_coercer(const coercer_type& coercer) = 0;
 
     /*!
      * Register a publisher into the property.
@@ -93,7 +97,7 @@ public:
      * \return a reference to this property for chaining
      * \throws uhd::assertion_error if called more than once
      */
-    virtual property<T> &set_publisher(const publisher_type &publisher) = 0;
+    virtual property<T>& set_publisher(const publisher_type& publisher) = 0;
 
     /*!
      * Register a subscriber into the property.
@@ -104,7 +108,7 @@ public:
      * \param subscriber the subscriber callback function
      * \return a reference to this property for chaining
      */
-    virtual property<T> &add_desired_subscriber(const subscriber_type &subscriber) = 0;
+    virtual property<T>& add_desired_subscriber(const subscriber_type& subscriber) = 0;
 
     /*!
      * Register a subscriber into the property.
@@ -115,7 +119,7 @@ public:
      * \param subscriber the subscriber callback function
      * \return a reference to this property for chaining
      */
-    virtual property<T> &add_coerced_subscriber(const subscriber_type &subscriber) = 0;
+    virtual property<T>& add_coerced_subscriber(const subscriber_type& subscriber) = 0;
 
     /*!
      * Update calls all subscribers w/ the current value.
@@ -123,7 +127,7 @@ public:
      * \return a reference to this property for chaining
      * \throws uhd::assertion_error
      */
-    virtual property<T> &update(void) = 0;
+    virtual property<T>& update(void) = 0;
 
     /*!
      * Set the new value and call all the necessary subscribers.
@@ -137,7 +141,7 @@ public:
      * \return a reference to this property for chaining
      * \throws uhd::assertion_error
      */
-    virtual property<T> &set(const T &value) = 0;
+    virtual property<T>& set(const T& value) = 0;
 
     /*!
      * Set a coerced value and call all subscribers.
@@ -150,7 +154,7 @@ public:
      * \return a reference to this property for chaining
      * \throws uhd::assertion_error
      */
-    virtual property<T> &set_coerced(const T &value) = 0;
+    virtual property<T>& set_coerced(const T& value) = 0;
 
     /*!
      * Get the current value of this property.
@@ -180,7 +184,8 @@ public:
 };
 
 template <typename T>
-property<T>::~property(void){
+property<T>::~property(void)
+{
     /* NOP */
 }
 
@@ -191,21 +196,23 @@ property<T>::~property(void){
  * Notice: we do not declare UHD_API on the whole structure
  * because MSVC will do weird things with std::string and linking.
  */
-struct fs_path : std::string{
+struct fs_path : std::string
+{
     UHD_API fs_path(void);
-    UHD_API fs_path(const char *);
-    UHD_API fs_path(const std::string &);
+    UHD_API fs_path(const char*);
+    UHD_API fs_path(const std::string&);
     UHD_API std::string leaf(void) const;
     UHD_API fs_path branch_path(void) const;
 };
 
-UHD_API fs_path operator/(const fs_path &, const fs_path &);
-UHD_API fs_path operator/(const fs_path &, size_t);
+UHD_API fs_path operator/(const fs_path&, const fs_path&);
+UHD_API fs_path operator/(const fs_path&, size_t);
 
 /*!
  * The property tree provides a file system structure for accessing properties.
  */
-class UHD_API property_tree : boost::noncopyable{
+class UHD_API property_tree : uhd::noncopyable
+{
 public:
     typedef boost::shared_ptr<property_tree> sptr;
 
@@ -217,35 +224,41 @@ public:
     static sptr make(void);
 
     //! Get a subtree with a new root starting at path
-    virtual sptr subtree(const fs_path &path) const = 0;
+    virtual sptr subtree(const fs_path& path) const = 0;
 
     //! Remove a property or directory (recursive)
-    virtual void remove(const fs_path &path) = 0;
+    virtual void remove(const fs_path& path) = 0;
 
     //! True if the path exists in the tree
-    virtual bool exists(const fs_path &path) const = 0;
+    virtual bool exists(const fs_path& path) const = 0;
 
     //! Get an iterable to all things in the given path
-    virtual std::vector<std::string> list(const fs_path &path) const = 0;
+    virtual std::vector<std::string> list(const fs_path& path) const = 0;
 
     //! Create a new property entry in the tree
-    template <typename T> property<T> &create(
-        const fs_path &path,
-        coerce_mode_t coerce_mode = AUTO_COERCE);
+    template <typename T>
+    property<T>& create(const fs_path& path, coerce_mode_t coerce_mode = AUTO_COERCE);
 
     //! Get access to a property in the tree
-    template <typename T> property<T> &access(const fs_path &path);
+    template <typename T>
+    property<T>& access(const fs_path& path);
+
+    //! Pop a property off the tree, and returns the property
+    template <typename T>
+    boost::shared_ptr<property<T> > pop(const fs_path& path);
 
 private:
+    //! Internal pop function
+    virtual boost::shared_ptr<void> _pop(const fs_path& path) = 0;
+
     //! Internal create property with wild-card type
-    virtual void _create(const fs_path &path, const boost::shared_ptr<void> &prop) = 0;
+    virtual void _create(const fs_path& path, const boost::shared_ptr<void>& prop) = 0;
 
     //! Internal access property with wild-card type
-    virtual boost::shared_ptr<void> &_access(const fs_path &path) const = 0;
-
+    virtual boost::shared_ptr<void>& _access(const fs_path& path) const = 0;
 };
 
-} //namespace uhd
+} // namespace uhd
 
 #include <uhd/property_tree.ipp>
 
