@@ -7,11 +7,10 @@
 #ifndef INCLUDED_LIBUHD_RFNOC_fir_block_ctrl_HPP
 #define INCLUDED_LIBUHD_RFNOC_fir_block_ctrl_HPP
 
-#include <uhd/rfnoc/source_block_ctrl_base.hpp>
 #include <uhd/rfnoc/sink_block_ctrl_base.hpp>
+#include <uhd/rfnoc/source_block_ctrl_base.hpp>
 
-namespace uhd {
-    namespace rfnoc {
+namespace uhd { namespace rfnoc {
 
 /*! \brief Block controller for the standard FIR RFNoC block.
  *
@@ -24,7 +23,8 @@ namespace uhd {
  * It will perform one FFT operation per incoming packet, treating it
  * as a vector of samples.
  */
-class UHD_RFNOC_API fir_block_ctrl : public source_block_ctrl_base, public sink_block_ctrl_base
+class UHD_RFNOC_API fir_block_ctrl : public source_block_ctrl_base,
+                                     public sink_block_ctrl_base
 {
 public:
     UHD_RFNOC_BLOCK_OBJECT(fir_block_ctrl)
@@ -34,7 +34,7 @@ public:
     // The length of \p taps must correspond the number of taps
     // in this block. If it's shorter, zeros will be padded.
     // If it's longer, throws a uhd::value_error.
-    virtual void set_taps(const std::vector<int> &taps) = 0;
+    virtual void set_taps(const std::vector<int>& taps) = 0;
 
     //! Returns the number of filter taps in this block.
     virtual size_t get_n_taps() const = 0;
@@ -43,4 +43,3 @@ public:
 }} /* namespace uhd::rfnoc */
 
 #endif /* INCLUDED_LIBUHD_RFNOC_fir_block_ctrl_HPP */
-// vim: sw=4 et:
