@@ -11,8 +11,7 @@
 #include <uhd/rfnoc/block_ctrl_base.hpp>
 #include <uhd/rfnoc/sink_node_ctrl.hpp>
 
-namespace uhd {
-    namespace rfnoc {
+namespace uhd { namespace rfnoc {
 
 /*! \brief Extends block_ctrl_base with input capabilities.
  *
@@ -41,7 +40,7 @@ public:
      * \returns The stream signature for port \p block_port
      * \throws uhd::runtime_error if \p block_port is not a valid port
      */
-    stream_sig_t get_input_signature(size_t block_port=0) const;
+    stream_sig_t get_input_signature(size_t block_port = 0) const;
 
     /*! Return a list of valid input ports.
      */
@@ -62,7 +61,19 @@ public:
      *
      * Returns the size of the buffer in bytes.
      */
-    size_t get_fifo_size(size_t block_port=0) const;
+    size_t get_fifo_size(size_t block_port = 0) const;
+
+    /*! Return the MTU size on a given block port.
+     *
+     * This is necessary for setting up transports, among other things.
+     *
+     * If the block port is not defined, it will return 0, and not throw.
+     *
+     * \param block_port The block port (0 through 15).
+     *
+     * Returns the MTU in bytes.
+     */
+    size_t get_mtu(size_t block_port = 0) const;
 
     /*! Configure flow control for incoming streams.
      *
@@ -70,31 +81,25 @@ public:
      * send out ACKs, telling the upstream block which packets have been consumed,
      * so the upstream block can increase his flow control credit.
      *
-     * In the default implementation, this just sets registers
-     * SR_FLOW_CTRL_CYCS_PER_ACK and SR_FLOW_CTRL_PKTS_PER_ACK accordingly.
+     * In the default implementation, this just sets register SR_FLOW_CTRL_PKTS_PER_ACK
+     * accordingly.
      *
      * Override this function if your block has port-specific flow control settings.
      *
-     * \param cycles Send an ACK after this many clock cycles.
-     *               Setting this to zero disables this type of flow control acknowledgement.
-     * \param packets Send an ACK after this many packets have been consumed.
-     *               Setting this to zero disables this type of flow control acknowledgement.
-     * \param block_port Set up flow control for a stream coming in on this particular block port.
+     * \param bytes Send an ACK after this many bytes have been consumed.
+     *              Setting this to zero disables flow control acknowledgement.
+     * \param block_port Set up flow control for a stream coming in on this particular
+     * block port.
      */
     virtual void configure_flow_control_in(
-            size_t cycles,
-            size_t packets,
-            size_t block_port=0
-    );
+        const size_t bytes, const size_t block_port = 0);
 
     /*! Configure the behaviour for errors on incoming packets
      *  (e.g. sequence errors).
      *
      *
      */
-    virtual void set_error_policy(
-        const std::string &policy
-    );
+    virtual void set_error_policy(const std::string& policy);
 
 protected:
     /***********************************************************************
@@ -104,13 +109,10 @@ protected:
      * the port has an input signature.
      */
     virtual size_t _request_input_port(
-            const size_t suggested_port,
-            const uhd::device_addr_t &args
-    ) const;
+        const size_t suggested_port, const uhd::device_addr_t& args) const;
 
 }; /* class sink_block_ctrl_base */
 
 }} /* namespace uhd::rfnoc */
 
 #endif /* INCLUDED_LIBUHD_TX_BLOCK_CTRL_BASE_HPP */
-// vim: sw=4 et:
