@@ -1,18 +1,8 @@
 //
 // Copyright 2013-2014 Ettus Research LLC
+// Copyright 2018 Ettus Research, a National Instruments Company
 //
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
 //
 
 #ifndef INCLUDED_UHD_TRANSPORT_NIRIO_NIRIO_INTERFACE_H
@@ -20,7 +10,7 @@
 
 #include <stdint.h>
 #include <boost/smart_ptr.hpp>
-#include <boost/noncopyable.hpp>
+#include <uhd/utils/noncopyable.hpp>
 #include <boost/thread/shared_mutex.hpp>
 #include <boost/thread/locks.hpp>
 #include <uhd/transport/nirio/nirio_driver_iface.h>
@@ -143,7 +133,7 @@ namespace uhd { namespace niusrprio
        uint32_t             version;
    };
 
-    class UHD_API niriok_proxy : public boost::noncopyable {
+    class UHD_API niriok_proxy : public uhd::noncopyable {
     public:
         typedef boost::shared_ptr<niriok_proxy> sptr;
 
@@ -262,7 +252,7 @@ namespace uhd { namespace niusrprio
         virtual void _close() = 0;
     };
 
-    class niriok_scoped_addr_space : public boost::noncopyable {
+    class niriok_scoped_addr_space : public uhd::noncopyable {
     public:
         explicit niriok_scoped_addr_space(niriok_proxy::sptr proxy, nirio_addr_space_t addr_space, nirio_status& status) :
             driver_proxy(proxy)
