@@ -1,18 +1,8 @@
 //
 // Copyright 2014 Ettus Research LLC
+// Copyright 2018 Ettus Research, a National Instruments Company
 //
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
 //
 
 #ifndef INCLUDED_UHD_USRP_CLOCK_OCTOCLOCK_EEPROM_HPP
@@ -23,7 +13,7 @@
 #include <uhd/types/dict.hpp>
 #include <string>
 
-namespace uhd{ namespace usrp_clock{
+namespace uhd { namespace usrp_clock {
 
 /*!
  * The OctoClock EEPROM object:
@@ -32,7 +22,8 @@ namespace uhd{ namespace usrp_clock{
  * Use the dictionary interface to get and set values.
  * Commit to the EEPROM to save changed settings.
  */
-class UHD_API octoclock_eeprom_t : public uhd::dict<std::string, std::string>{
+class UHD_API octoclock_eeprom_t : public uhd::dict<std::string, std::string>
+{
 public:
     //! Make a new empty OctoClock EEPROM handler
     octoclock_eeprom_t(void);
@@ -54,10 +45,8 @@ private:
     uint32_t _proto_ver;
     void _load();
     void _store() const;
-
 };
 
-} //namespace
-} //namespace
+}} // namespace uhd::usrp_clock
 
 #endif /* INCLUDED_UHD_USRP_CLOCK_OCTOCLOCK_EEPROM_HPP */
