@@ -30,7 +30,8 @@
  * \param _name the name of the pimpl class
  */
 #define UHD_PIMPL_DECL(_name) \
-    struct _name; boost::shared_ptr<_name>
+    struct _name;             \
+    boost::shared_ptr<_name>
 
 /*!
  * Make an instance of a pimpl in a source file.
@@ -39,7 +40,6 @@
  * \param _name the name of the pimpl class
  * \param _args the constructor args for the pimpl
  */
-#define UHD_PIMPL_MAKE(_name, _args) \
-    boost::shared_ptr<_name>(new _name _args)
+#define UHD_PIMPL_MAKE(_name, _args) boost::shared_ptr<_name>(new _name _args)
 
 #endif /* INCLUDED_UHD_UTILS_PIMPL_HPP */
