@@ -1,91 +1,14 @@
 //
-// Copyright 2013 Ettus Research LLC
+// Copyright 2017 Ettus Research LLC
+// Copyright 2018 Ettus Research, a National Instruments Company
 //
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
 //
 
-#include "convert_common.hpp"
-#include <uhd/utils/byteswap.hpp>
-#include <uhd/utils/msg.hpp>
-#include <boost/math/special_functions/round.hpp>
-#include <vector>
+#include "convert_unpack_sc12.hpp"
 
 using namespace uhd::convert;
 
-typedef uint32_t (*tohost32_type)(uint32_t);
-
-/* C language specification requires this to be packed
- * (i.e., line0, line1, line2 will be in adjacent memory locations).
- * If this was not true, we'd need compiler flags here to specify
- * alignment/packing.
- */
-struct item32_sc12_3x
-{
-    item32_t line0;
-    item32_t line1;
-    item32_t line2;
-};
-
-/*
- * convert_sc12_item32_3_to_star_4 takes in 3 lines with 32 bit each
- * and converts them 4 samples of type 'std::complex<type>'.
- * The structure of the 3 lines is as follows:
- *  _ _ _ _ _ _ _ _
- * |_ _ _1_ _ _|_ _|
- * |_2_ _ _|_ _ _3_|
- * |_ _|_ _ _4_ _ _|
- *
- * The numbers mark the position of one complex sample.
- */
-template <typename type, tohost32_type tohost>
-void convert_sc12_item32_3_to_star_4
-(
-    const item32_sc12_3x &input,
-    std::complex<type> &out0,
-    std::complex<type> &out1,
-    std::complex<type> &out2,
-    std::complex<type> &out3,
-    const double scalar
-)
-{
-    //step 0: extract the lines from the input buffer
-    const item32_t line0 = tohost(input.line0);
-    const item32_t line1 = tohost(input.line1);
-    const item32_t line2 = tohost(input.line2);
-    const uint64_t line01 = (uint64_t(line0) << 32) | line1;
-    const uint64_t line12 = (uint64_t(line1) << 32) | line2;
-
-    //step 1: shift out and mask off the individual numbers
-    const type i0 = type(int16_t((line0 >> 16) & 0xfff0)*scalar);
-    const type q0 = type(int16_t((line0 >> 4) & 0xfff0)*scalar);
-
-    const type i1 = type(int16_t((line01 >> 24) & 0xfff0)*scalar);
-    const type q1 = type(int16_t((line1 >> 12) & 0xfff0)*scalar);
-
-    const type i2 = type(int16_t((line1 >> 0) & 0xfff0)*scalar);
-    const type q2 = type(int16_t((line12 >> 20) & 0xfff0)*scalar);
-
-    const type i3 = type(int16_t((line2 >> 8) & 0xfff0)*scalar);
-    const type q3 = type(int16_t((line2 << 4) & 0xfff0)*scalar);
-
-    //step 2: load the outputs
-    out0 = std::complex<type>(i0, q0);
-    out1 = std::complex<type>(i1, q1);
-    out2 = std::complex<type>(i2, q2);
-    out3 = std::complex<type>(i3, q3);
-}
-
 template <typename type, tohost32_type tohost>
 struct convert_sc12_item32_1_to_star_1 : public converter
 {
@@ -193,18 +116,32 @@ static converter::sptr make_convert_sc12_item32_be_1_to_fc32_1(void)
     return converter::sptr(new convert_sc12_item32_1_to_star_1<float, uhd::ntohx>());
 }
 
+static converter::sptr make_convert_sc12_item32_le_1_to_sc16_1(void)
+{
+    return converter::sptr(new convert_sc12_item32_1_to_star_1<short, uhd::wtohx>());
+}
+
+static converter::sptr make_convert_sc12_item32_be_1_to_sc16_1(void)
+{
+    return converter::sptr(new convert_sc12_item32_1_to_star_1<short, uhd::ntohx>());
+}
+
 UHD_STATIC_BLOCK(register_convert_unpack_sc12)
 {
     uhd::convert::register_bytes_per_item("sc12", 3/*bytes*/);
-
     uhd::convert::id_type id;
     id.num_inputs = 1;
     id.num_outputs = 1;
-    id.output_format = "fc32";
 
+    id.output_format = "fc32";
     id.input_format = "sc12_item32_le";
     uhd::convert::register_converter(id, &make_convert_sc12_item32_le_1_to_fc32_1, PRIORITY_GENERAL);
-
     id.input_format = "sc12_item32_be";
     uhd::convert::register_converter(id, &make_convert_sc12_item32_be_1_to_fc32_1, PRIORITY_GENERAL);
+
+    id.output_format = "sc16";
+    id.input_format = "sc12_item32_le";
+    uhd::convert::register_converter(id, &make_convert_sc12_item32_le_1_to_sc16_1, PRIORITY_GENERAL);
+    id.input_format = "sc12_item32_be";
+    uhd::convert::register_converter(id, &make_convert_sc12_item32_be_1_to_sc16_1, PRIORITY_GENERAL);
 }
