@@ -1,25 +1,14 @@
 //
 // Copyright 2016 Ettus Research
+// Copyright 2018 Ettus Research, a National Instruments Company
 //
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
 //
 
-#include "expert_container.hpp"
+#include <uhdlib/experts/expert_container.hpp>
 #include <uhd/exception.hpp>
-#include <uhd/utils/msg.hpp>
+#include <uhd/utils/log.hpp>
 #include <boost/format.hpp>
-#include <boost/foreach.hpp>
 #include <boost/function.hpp>
 #include <boost/bind.hpp>
 #include <boost/make_shared.hpp>
@@ -185,7 +174,7 @@ public:
             EX_LOG(1, "cycle check ... PASSED");
         } else {
             EX_LOG(1, "cycle check ... ERROR!!!");
-            BOOST_FOREACH(const std::string& e, back_edges) {
+            for(const std::string& e:  back_edges) {
                 EX_LOG(2, "back edge: " + e);
             }
         }
@@ -193,7 +182,7 @@ public:
 
         //Test 2: Check data node input and output edges
         std::vector<std::string> data_node_issues;
-        BOOST_FOREACH(const vertex_map_t::value_type& v, _datanode_map) {
+        for(const vertex_map_t::value_type& v:  _datanode_map) {
             size_t in_count = 0, out_count = 0;
             for (std::pair<edge_iter, edge_iter> ei = boost::edges(_expert_dag);
                  ei.first != ei.second;
@@ -238,7 +227,7 @@ public:
             EX_LOG(1, "data node check ... PASSED");
         } else {
             EX_LOG(1, "data node check ... WARNING!");
-            BOOST_FOREACH(const std::string& i, data_node_issues) {
+            for(const std::string& i:  data_node_issues) {
                 EX_LOG(2, i);
             }
         }
@@ -246,7 +235,7 @@ public:
 
         //Test 3: Check worker node input and output edges
         std::vector<std::string> worker_issues;
-        BOOST_FOREACH(const vertex_map_t::value_type& v, _worker_map) {
+        for(const vertex_map_t::value_type& v:  _worker_map) {
             size_t in_count = 0, out_count = 0;
             for (std::pair<edge_iter, edge_iter> ei = boost::edges(_expert_dag);
                  ei.first != ei.second;
@@ -268,7 +257,7 @@ public:
             EX_LOG(1, "worker check ... PASSED");
         } else {
             EX_LOG(1, "worker check ... WARNING!");
-            BOOST_FOREACH(const std::string& i, worker_issues) {
+            for(const std::string& i:  worker_issues) {
                 EX_LOG(2, i);
             }
         }
@@ -347,7 +336,7 @@ protected:
             _worker_map.insert(vertex_map_t::value_type(worker->get_name(), gr_node));
 
             //For each input, add an edge from the input to this node
-            BOOST_FOREACH(const std::string& node_name, worker->get_inputs()) {
+            for(const std::string& node_name:  worker->get_inputs()) {
                 vertex_map_t::const_iterator node = _datanode_map.find(node_name);
                 if (node != _datanode_map.end()) {
                     boost::add_edge((*node).second, gr_node, _expert_dag);
@@ -358,7 +347,7 @@ protected:
             }
 
             //For each output, add an edge from this node to the output
-            BOOST_FOREACH(const std::string& node_name, worker->get_outputs()) {
+            for(const std::string& node_name:  worker->get_outputs()) {
                 vertex_map_t::const_iterator node = _datanode_map.find(node_name);
                 if (node != _datanode_map.end()) {
                     boost::add_edge(gr_node, (*node).second, _expert_dag);
@@ -423,7 +412,7 @@ private:
             boost::depth_first_search(_expert_dag, boost::visitor(cdet_vis));
             if (not back_edges.empty()) {
                 std::string edges;
-                BOOST_FOREACH(const std::string& e, back_edges) {
+                for(const std::string& e:  back_edges) {
                     edges += "* " + e + "";
                 }
                 throw uhd::runtime_error("Cannot resolve expert because it has at least one cycle!\n"
@@ -514,7 +503,7 @@ private:
     {
         std::string indents;
         for (size_t i = 0; i < depth; i++) indents += "- ";
-        UHD_MSG(fastpath) << "[expert::" + _name + "] " << indents << str << std::endl;
+        UHD_LOG_DEBUG("EXPERT","[expert::" + _name + "] " << indents << str)
     }
 
 private:
