@@ -1,7 +1,7 @@
 //
 // Copyright 2018 Ettus Research, A National Instruments Company
 //
-// SPDX-License-Identifier: GPL-3.0
+// SPDX-License-Identifier: GPL-3.0-or-later
 //
 
 #ifndef INCLUDED_LMX2592_HPP
@@ -13,13 +13,13 @@
 #include <uhd/utils/safe_call.hpp>
 #include <boost/format.hpp>
 #include <boost/function.hpp>
-#include <boost/math/common_factor_rt.hpp> //gcd
 #include <algorithm>
 #include <cstdint>
 #include <utility>
 #include <vector>
 
-class lmx2592_iface {
+class lmx2592_iface
+{
 public:
     typedef std::shared_ptr<lmx2592_iface> sptr;
 
@@ -37,7 +37,9 @@ public:
 
     enum mash_order_t { INT_N, FIRST, SECOND, THIRD, FOURTH };
 
-    virtual double set_frequency(double target_freq) = 0;
+    virtual double set_frequency(double target_freq,
+        const bool spur_dodging,
+        const double spur_dodging_threshold) = 0;
 
     virtual void set_mash_order(mash_order_t mash_order) = 0;
 
