@@ -10,11 +10,11 @@
 
 #include <uhd/config.hpp>
 #include <uhd/types/serial.hpp>
-#include <boost/utility.hpp>
-#include <boost/shared_ptr.hpp>
+#include <uhd/utils/noncopyable.hpp>
 #include <uhd/types/wb_iface.hpp>
+#include <boost/shared_ptr.hpp>
 
-class spi_core_3000 : boost::noncopyable, public uhd::spi_iface
+class spi_core_3000 : uhd::noncopyable, public uhd::spi_iface
 {
 public:
     typedef boost::shared_ptr<spi_core_3000> sptr;
