@@ -24,34 +24,28 @@ static double _get_output_samp_rate(rate_node_ctrl::sptr node, size_t port)
 
 
 // FIXME add recursion limiters (i.e. list of explored nodes)
-double rate_node_ctrl::get_input_samp_rate(
-        size_t /* port */
-) {
+double rate_node_ctrl::get_input_samp_rate(size_t /* port */
+)
+{
     try {
         return find_downstream_unique_property<rate_node_ctrl, double>(
-                boost::bind(_get_input_samp_rate, _1, _2),
-                RATE_UNDEFINED
-        );
-    } catch (const uhd::runtime_error &ex) {
-        throw uhd::runtime_error(str(
-            boost::format("Multiple sampling rates downstream of %s: %s.")
-            % unique_id() % ex.what()
-        ));
+            boost::bind(_get_input_samp_rate, _1, _2), RATE_UNDEFINED);
+    } catch (const uhd::runtime_error& ex) {
+        throw uhd::runtime_error(
+            str(boost::format("Multiple sampling rates downstream of %s: %s.")
+                % unique_id() % ex.what()));
     }
 }
 
-double rate_node_ctrl::get_output_samp_rate(
-        size_t /* port */
-) {
+double rate_node_ctrl::get_output_samp_rate(size_t /* port */
+)
+{
     try {
         return find_upstream_unique_property<rate_node_ctrl, double>(
-                boost::bind(_get_output_samp_rate, _1, _2),
-                RATE_UNDEFINED
-        );
-    } catch (const uhd::runtime_error &ex) {
-        throw uhd::runtime_error(str(
-            boost::format("Multiple sampling rates upstream of %s: %s.")
-            % unique_id() % ex.what()
-        ));
+            boost::bind(_get_output_samp_rate, _1, _2), RATE_UNDEFINED);
+    } catch (const uhd::runtime_error& ex) {
+        throw uhd::runtime_error(
+            str(boost::format("Multiple sampling rates upstream of %s: %s.") % unique_id()
+                % ex.what()));
     }
 }
