@@ -5,17 +5,13 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 //
 
-#include <uhd/rfnoc/stream_sig.hpp>
 #include <uhd/convert.hpp>
+#include <uhd/rfnoc/stream_sig.hpp>
 #include <boost/format.hpp>
 
 using namespace uhd::rfnoc;
 
-stream_sig_t::stream_sig_t() :
-    item_type(""),
-    vlen(0),
-    packet_size(0),
-    is_bursty(false)
+stream_sig_t::stream_sig_t() : item_type(""), vlen(0), packet_size(0), is_bursty(false)
 {
     // nop
 }
@@ -23,19 +19,13 @@ stream_sig_t::stream_sig_t() :
 std::string stream_sig_t::to_string()
 {
     return str(
-        boost::format(
-            "%s,vlen=%d,packet_size=%d"
-        ) % item_type % vlen % packet_size
-    );
+        boost::format("%s,vlen=%d,packet_size=%d") % item_type % vlen % packet_size);
 }
 
 std::string stream_sig_t::to_pp_string()
 {
-    return str(
-        boost::format(
-            "Data type: %s  | Vector Length: %d | Packet size: %d"
-        ) % item_type % vlen % packet_size
-    );
+    return str(boost::format("Data type: %s  | Vector Length: %d | Packet size: %d")
+               % item_type % vlen % packet_size);
 }
 
 size_t stream_sig_t::get_bytes_per_item() const
@@ -47,10 +37,11 @@ size_t stream_sig_t::get_bytes_per_item() const
     return uhd::convert::get_bytes_per_item(item_type);
 }
 
-bool stream_sig_t::is_compatible(const stream_sig_t &output_sig, const stream_sig_t &input_sig)
+bool stream_sig_t::is_compatible(
+    const stream_sig_t& output_sig, const stream_sig_t& input_sig)
 {
     /// Item types:
-    if (not (input_sig.item_type.empty() or output_sig.item_type.empty())
+    if (not(input_sig.item_type.empty() or output_sig.item_type.empty())
         and input_sig.item_type != output_sig.item_type) {
         return false;
     }
