@@ -5,16 +5,16 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 //
 
-#include <uhd/transport/zero_copy_flow_ctrl.hpp>
 #include <uhd/transport/bounded_buffer.hpp>
 #include <uhd/transport/buffer_pool.hpp>
+#include <uhd/transport/zero_copy_flow_ctrl.hpp>
 #include <uhd/utils/log.hpp>
 #include <uhd/utils/safe_call.hpp>
+#include <boost/bind.hpp>
 #include <boost/format.hpp>
 #include <boost/make_shared.hpp>
 #include <boost/thread/mutex.hpp>
 #include <boost/thread/thread.hpp>
-#include <boost/bind.hpp>
 
 using namespace uhd;
 using namespace uhd::transport;
@@ -24,11 +24,8 @@ typedef bounded_buffer<managed_send_buffer::sptr> bounded_buffer_t;
 class zero_copy_flow_ctrl_msb : public managed_send_buffer
 {
 public:
-    zero_copy_flow_ctrl_msb(
-        flow_ctrl_func flow_ctrl
-    ) :
-        _mb(nullptr),
-        _flow_ctrl(flow_ctrl)
+    zero_copy_flow_ctrl_msb(flow_ctrl_func flow_ctrl)
+        : _mb(nullptr), _flow_ctrl(flow_ctrl)
     {
         /* NOP */
     }
@@ -40,18 +37,18 @@ public:
 
     void release()
     {
-        if (_mb)
-        {
+        if (_mb) {
             _mb->commit(size());
-            while (_flow_ctrl and not _flow_ctrl(_mb)) {}
+            while (_flow_ctrl and not _flow_ctrl(_mb)) {
+            }
             _mb.reset();
         }
     }
 
-    UHD_INLINE sptr get(sptr &mb)
+    UHD_INLINE sptr get(sptr& mb)
     {
         _mb = mb;
-        return make(this, _mb->cast<void *>(), _mb->size());
+        return make(this, _mb->cast<void*>(), _mb->size());
     }
 
 private:
@@ -62,11 +59,7 @@ private:
 class zero_copy_flow_ctrl_mrb : public managed_recv_buffer
 {
 public:
-    zero_copy_flow_ctrl_mrb(
-        flow_ctrl_func flow_ctrl
-    ) :
-        _mb(nullptr),
-        _flow_ctrl(flow_ctrl)
+    zero_copy_flow_ctrl_mrb(flow_ctrl_func flow_ctrl) : _mb(NULL), _flow_ctrl(flow_ctrl)
     {
         /* NOP */
     }
@@ -78,18 +71,17 @@ public:
 
     void release()
     {
-        if (_mb)
-        {
-            _mb->commit(size());
-            while (_flow_ctrl and not _flow_ctrl(_mb)) {}
+        if (_mb) {
             _mb.reset();
         }
     }
 
-    UHD_INLINE sptr get(sptr &mb)
+    UHD_INLINE sptr get(sptr& mb)
     {
         _mb = mb;
-        return make(this, _mb->cast<void *>(), _mb->size());
+        while (_flow_ctrl and not _flow_ctrl(_mb)) {
+        }
+        return make(this, _mb->cast<void*>(), _mb->size());
     }
 
 private:
@@ -102,36 +94,35 @@ private:
  * An intermediate transport that utilizes threading to free
  * the main thread from any receive work.
  **********************************************************************/
-class zero_copy_flow_ctrl_impl : public zero_copy_flow_ctrl {
+class zero_copy_flow_ctrl_impl : public zero_copy_flow_ctrl
+{
 public:
     typedef boost::shared_ptr<zero_copy_flow_ctrl_impl> sptr;
 
     zero_copy_flow_ctrl_impl(zero_copy_if::sptr transport,
         flow_ctrl_func send_flow_ctrl,
-        flow_ctrl_func recv_flow_ctrl) :
-        _transport(transport),
-        _send_buffers(transport->get_num_send_frames()),
-        _recv_buffers(transport->get_num_recv_frames()),
-        _send_buff_index(0),
-        _recv_buff_index(0),
-        _send_flow_ctrl(send_flow_ctrl),
-        _recv_flow_ctrl(recv_flow_ctrl)
+        flow_ctrl_func recv_flow_ctrl)
+        : _transport(transport)
+        , _send_buffers(transport->get_num_send_frames())
+        , _recv_buffers(transport->get_num_recv_frames())
+        , _send_buff_index(0)
+        , _recv_buff_index(0)
+        , _send_flow_ctrl(send_flow_ctrl)
+        , _recv_flow_ctrl(recv_flow_ctrl)
     {
         UHD_LOG_TRACE("TRANSPORT", "Created zero_copy_flow_ctrl");
 
-        for (size_t i = 0; i < transport->get_num_send_frames(); i++)
-        {
-            _send_buffers[i] = boost::make_shared<zero_copy_flow_ctrl_msb>(_send_flow_ctrl);
+        for (size_t i = 0; i < transport->get_num_send_frames(); i++) {
+            _send_buffers[i] =
+                boost::make_shared<zero_copy_flow_ctrl_msb>(_send_flow_ctrl);
         }
-        for (size_t i = 0; i < transport->get_num_recv_frames(); i++)
-        {
-            _recv_buffers[i] = boost::make_shared<zero_copy_flow_ctrl_mrb>(_recv_flow_ctrl);
+        for (size_t i = 0; i < transport->get_num_recv_frames(); i++) {
+            _recv_buffers[i] =
+                boost::make_shared<zero_copy_flow_ctrl_mrb>(_recv_flow_ctrl);
         }
     }
 
-    ~zero_copy_flow_ctrl_impl()
-    {
-    }
+    ~zero_copy_flow_ctrl_impl() {}
 
     /*******************************************************************
      * Receive implementation:
@@ -141,9 +132,9 @@ public:
     {
         managed_recv_buffer::sptr ptr;
         managed_recv_buffer::sptr buff = _transport->get_recv_buff(timeout);
-        if (buff)
-        {
-            boost::shared_ptr<zero_copy_flow_ctrl_mrb> mb = _recv_buffers[_recv_buff_index++];
+        if (buff) {
+            boost::shared_ptr<zero_copy_flow_ctrl_mrb> mb =
+                _recv_buffers[_recv_buff_index++];
             _recv_buff_index %= _recv_buffers.size();
             ptr = mb->get(buff);
         }
@@ -168,9 +159,9 @@ public:
     {
         managed_send_buffer::sptr ptr;
         managed_send_buffer::sptr buff = _transport->get_send_buff(timeout);
-        if (buff)
-        {
-            boost::shared_ptr<zero_copy_flow_ctrl_msb> mb = _send_buffers[_send_buff_index++];
+        if (buff) {
+            boost::shared_ptr<zero_copy_flow_ctrl_msb> mb =
+                _send_buffers[_send_buff_index++];
             _send_buff_index %= _send_buffers.size();
             ptr = mb->get(buff);
         }
@@ -192,8 +183,8 @@ private:
     zero_copy_if::sptr _transport;
 
     // buffers
-    std::vector< boost::shared_ptr<zero_copy_flow_ctrl_msb> > _send_buffers;
-    std::vector< boost::shared_ptr<zero_copy_flow_ctrl_mrb> > _recv_buffers;
+    std::vector<boost::shared_ptr<zero_copy_flow_ctrl_msb>> _send_buffers;
+    std::vector<boost::shared_ptr<zero_copy_flow_ctrl_mrb>> _recv_buffers;
     size_t _send_buff_index;
     size_t _recv_buff_index;
 
@@ -202,15 +193,12 @@ private:
     flow_ctrl_func _recv_flow_ctrl;
 };
 
-zero_copy_flow_ctrl::sptr zero_copy_flow_ctrl::make(
-        zero_copy_if::sptr transport,
-        flow_ctrl_func send_flow_ctrl,
-        flow_ctrl_func recv_flow_ctrl
-)
+zero_copy_flow_ctrl::sptr zero_copy_flow_ctrl::make(zero_copy_if::sptr transport,
+    flow_ctrl_func send_flow_ctrl,
+    flow_ctrl_func recv_flow_ctrl)
 {
     zero_copy_flow_ctrl_impl::sptr zero_copy_flow_ctrl(
-        new zero_copy_flow_ctrl_impl(transport, send_flow_ctrl, recv_flow_ctrl)
-    );
+        new zero_copy_flow_ctrl_impl(transport, send_flow_ctrl, recv_flow_ctrl));
 
     return zero_copy_flow_ctrl;
 }
