@@ -276,6 +276,7 @@ UHD_STATIC_BLOCK(register_b200_device)
 b200_impl::b200_impl(const uhd::device_addr_t& device_addr, usb_device_handle::sptr &handle) :
     _product(B200), // Some safe value
     _revision(0),
+    _enable_user_regs(device_addr.has_key("enable_user_regs")),
     _time_source(UNKNOWN),
     _tick_rate(0.0) // Forces a clock initialization at startup
 {
@@ -796,15 +797,6 @@ b200_impl::~b200_impl(void)
 /***********************************************************************
  * setup radio control objects
  **********************************************************************/
-
-void lambda_set_bool_prop(boost::weak_ptr<property_tree> tree_wptr, fs_path path, bool value, double)
-{
-    property_tree::sptr tree = tree_wptr.lock();
-    if (tree) {
-        tree->access<bool>(path).set(value);
-    }
-}
-
 void b200_impl::setup_radio(const size_t dspno)
 {
     radio_perifs_t &perif = _radio_perifs[dspno];
@@ -846,6 +838,18 @@ void b200_impl::setup_radio(const size_t dspno)
     perif.duc = tx_dsp_core_3000::make(perif.ctrl, TOREG(SR_TX_DSP));
     perif.duc->set_link_rate(10e9/8); //whatever
     perif.duc->set_freq(tx_dsp_core_3000::DEFAULT_CORDIC_FREQ);
+    if (_enable_user_regs) {
+        UHD_LOG_DEBUG("B200", "Enabling user settings registers");
+        perif.user_settings = user_settings_core_3000::make(perif.ctrl,
+            TOREG(SR_USER_SR_BASE),
+            TOREG(SR_USER_RB_ADDR)
+        );
+        if (!perif.user_settings) {
+            const std::string error_msg = "Failed to create user settings bus!";
+            UHD_LOG_ERROR("B200", error_msg);
+            throw uhd::runtime_error(error_msg);
+        }
+    }
 
     ////////////////////////////////////////////////////////////////////
     // create time control objects
@@ -863,7 +867,12 @@ void b200_impl::setup_radio(const size_t dspno)
     _tree->create<bool>(rx_dsp_path / "rate" / "set").set(false);
     _tree->access<double>(rx_dsp_path / "rate" / "value")
         .set_coercer(boost::bind(&b200_impl::coerce_rx_samp_rate, this, perif.ddc, dspno, _1))
-        .add_coerced_subscriber(boost::bind(&lambda_set_bool_prop, boost::weak_ptr<property_tree>(_tree), rx_dsp_path / "rate" / "set", true, _1))
+        .add_coerced_subscriber([this, rx_dsp_path](const double){
+            if (this->_tree) {
+                this->_tree->access<bool>(rx_dsp_path / "rate" / "set")
+                    .set(true);
+            }
+        })
         .add_coerced_subscriber(boost::bind(&b200_impl::update_rx_samp_rate, this, dspno, _1))
     ;
     _tree->create<stream_cmd_t>(rx_dsp_path / "stream_cmd")
@@ -881,7 +890,12 @@ void b200_impl::setup_radio(const size_t dspno)
     _tree->create<bool>(tx_dsp_path / "rate" / "set").set(false);
     _tree->access<double>(tx_dsp_path / "rate" / "value")
         .set_coercer(boost::bind(&b200_impl::coerce_tx_samp_rate, this, perif.duc, dspno, _1))
-        .add_coerced_subscriber(boost::bind(&lambda_set_bool_prop, boost::weak_ptr<property_tree>(_tree), tx_dsp_path / "rate" / "set", true, _1))
+        .add_coerced_subscriber([this, tx_dsp_path](const double){
+            if (this->_tree) {
+                this->_tree->access<bool>(tx_dsp_path / "rate" / "set")
+                    .set(true);
+            }
+        })
         .add_coerced_subscriber(boost::bind(&b200_impl::update_tx_samp_rate, this, dspno, _1))
     ;
     _tree->access<double>(mb_path / "tick_rate")
@@ -925,6 +939,11 @@ void b200_impl::setup_radio(const size_t dspno)
             _tree->create<std::vector<std::string> >(rf_fe_path / "antenna" / "options").set(ants);
             _tree->create<std::string>(rf_fe_path / "antenna" / "value").set("TX/RX");
         }
+
+        if (_enable_user_regs) {
+            _tree->create<uhd::wb_iface::sptr>(rf_fe_path / "user_settings/iface")
+                .set(perif.user_settings);
+        }
     }
 }
 
@@ -1243,9 +1262,9 @@ void b200_impl::update_atrs(void)
         const bool enb_rx = bool(perif.rx_streamer.lock());
         const bool enb_tx = bool(perif.tx_streamer.lock());
         const bool is_rx2 = perif.ant_rx2;
-        const size_t rxonly = (enb_rx)? ((is_rx2)? STATE_RX1_RX2 : STATE_RX1_TXRX) : STATE_OFF;
-        const size_t txonly = (enb_tx)? (STATE_TX1_TXRX) : STATE_OFF;
-        size_t fd = STATE_OFF;
+        const uint32_t rxonly = (enb_rx)? ((is_rx2)? STATE_RX1_RX2 : STATE_RX1_TXRX) : STATE_OFF;
+        const uint32_t txonly = (enb_tx)? (STATE_TX1_TXRX) : STATE_OFF;
+        uint32_t fd = STATE_OFF;
         if (enb_rx and enb_tx) fd = STATE_FDX1_TXRX;
         if (enb_rx and not enb_tx) fd = rxonly;
         if (not enb_rx and enb_tx) fd = txonly;
@@ -1261,9 +1280,9 @@ void b200_impl::update_atrs(void)
         const bool enb_rx = bool(perif.rx_streamer.lock());
         const bool enb_tx = bool(perif.tx_streamer.lock());
         const bool is_rx2 = perif.ant_rx2;
-        const size_t rxonly = (enb_rx)? ((is_rx2)? STATE_RX2_RX2 : STATE_RX2_TXRX) : STATE_OFF;
-        const size_t txonly = (enb_tx)? (STATE_TX2_TXRX) : STATE_OFF;
-        size_t fd = STATE_OFF;
+        const uint32_t rxonly = (enb_rx)? ((is_rx2)? STATE_RX2_RX2 : STATE_RX2_TXRX) : STATE_OFF;
+        const uint32_t txonly = (enb_tx)? (STATE_TX2_TXRX) : STATE_OFF;
+        uint32_t fd = STATE_OFF;
         if (enb_rx and enb_tx) fd = STATE_FDX2_TXRX;
         if (enb_rx and not enb_tx) fd = rxonly;
         if (not enb_rx and enb_tx) fd = txonly;
