@@ -32,11 +32,13 @@
 #include <uhdlib/usrp/cores/radio_ctrl_core_3000.hpp>
 #include <uhdlib/usrp/cores/rx_dsp_core_3000.hpp>
 #include <uhdlib/usrp/cores/tx_dsp_core_3000.hpp>
+#include <uhdlib/usrp/cores/user_settings_core_3000.hpp>
 #include <uhdlib/usrp/common/recv_packet_demuxer_3000.hpp>
 #include <uhdlib/usrp/common/ad936x_manager.hpp>
 #include <uhdlib/usrp/common/adf4001_ctrl.hpp>
 #include <boost/assign.hpp>
 #include <boost/weak_ptr.hpp>
+#include <mutex>
 
 static const uint8_t  B200_FW_COMPAT_NUM_MAJOR = 8;
 static const uint8_t  B200_FW_COMPAT_NUM_MINOR = 0;
@@ -44,8 +46,8 @@ static const uint16_t B200_FPGA_COMPAT_NUM = 16;
 static const uint16_t B205_FPGA_COMPAT_NUM = 7;
 static const double          B200_BUS_CLOCK_RATE = 100e6;
 static const uint32_t B200_GPSDO_ST_NONE = 0x83;
-static const size_t B200_MAX_RATE_USB2              =  53248000; // bytes/s
-static const size_t B200_MAX_RATE_USB3              = 500000000; // bytes/s
+static constexpr double B200_MAX_RATE_USB2              =  53248000; // bytes/s
+static constexpr double B200_MAX_RATE_USB3              = 500000000; // bytes/s
 
 #define FLIP_SID(sid) (((sid)<<16)|((sid)>>16))
 
@@ -127,6 +129,9 @@ private:
     b200_product_t  _product;
     size_t          _revision;
     bool            _gpsdo_capable;
+    //! This flag is true if the FPGA has custom (user) registers and access to
+    // those needs to be enabled from software.
+    const bool      _enable_user_regs;
 
     //controllers
     b200_iface::sptr _iface;
@@ -145,7 +150,7 @@ private:
     boost::weak_ptr<uhd::rx_streamer> _rx_streamer;
     boost::weak_ptr<uhd::tx_streamer> _tx_streamer;
 
-    boost::mutex _transport_setup_mutex;
+    std::mutex _transport_setup_mutex;
 
     //async ctrl + msgs
     uhd::msg_task::sptr _async_task;
@@ -189,6 +194,7 @@ private:
         tx_dsp_core_3000::sptr duc;
         boost::weak_ptr<uhd::rx_streamer> rx_streamer;
         boost::weak_ptr<uhd::tx_streamer> tx_streamer;
+        user_settings_core_3000::sptr user_settings;
         bool ant_rx2;
     };
     std::vector<radio_perifs_t> _radio_perifs;
