@@ -1,18 +1,8 @@
 //
 // Copyright 2013 Ettus Research LLC
+// Copyright 2018 Ettus Research, a National Instruments Company
 //
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
 //
 
 #include "b200_uart.hpp"
@@ -20,10 +10,9 @@
 #include <uhd/transport/bounded_buffer.hpp>
 #include <uhd/transport/vrt_if_packet.hpp>
 #include <uhd/utils/byteswap.hpp>
-#include <uhd/utils/msg.hpp>
+#include <uhd/utils/log.hpp>
 #include <uhd/types/time_spec.hpp>
 #include <uhd/exception.hpp>
-#include <boost/foreach.hpp>
 
 using namespace uhd;
 using namespace uhd::transport;
@@ -69,7 +58,7 @@ struct b200_uart_impl : b200_uart
 
     void write_uart(const std::string &buff)
     {
-        BOOST_FOREACH(const char ch, buff)
+        for(const char ch:  buff)
         {
             this->send_char(ch);
         }
