@@ -1,25 +1,16 @@
 //
 // Copyright 2011-2012,2014 Ettus Research LLC
+// Copyright 2018 Ettus Research, a National Instruments Company
 //
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
 //
 
-#include "i2c_core_200.hpp"
 #include <uhd/exception.hpp>
-#include <uhd/utils/msg.hpp>
-#include <boost/thread/thread.hpp> //sleep
+#include <uhd/utils/log.hpp>
+#include <uhdlib/usrp/cores/i2c_core_200.hpp>
 #include <boost/thread/mutex.hpp>
+#include <chrono>
+#include <thread>
 
 #define REG_I2C_WR_PRESCALER_LO (1 << 3) | 0
 #define REG_I2C_WR_PRESCALER_HI (1 << 3) | 1
@@ -128,9 +119,9 @@ private:
     void i2c_wait(void) {
         for (size_t i = 0; i < 100; i++){
             if ((this->peek(REG_I2C_RD_ST) & I2C_ST_TIP) == 0) return;
-            boost::this_thread::sleep(boost::posix_time::milliseconds(1));
+            std::this_thread::sleep_for(std::chrono::milliseconds(1));
         }
-        UHD_MSG(error) << "i2c_core_200: i2c_wait timeout" << std::endl;
+        UHD_LOGGER_ERROR("CORES") << "i2c_core_200: i2c_wait timeout" ;
     }
 
     bool wait_chk_ack(void){
