@@ -7,6 +7,7 @@
 
 #include <uhdlib/usrp/cores/tx_frontend_core_200.hpp>
 #include <uhd/types/dict.hpp>
+#include <uhd/types/ranges.hpp>
 #include <uhd/exception.hpp>
 #include <boost/assign/list_of.hpp>
 #include <boost/math/special_functions/round.hpp>
@@ -23,6 +24,11 @@ using namespace uhd;
 const std::complex<double> tx_frontend_core_200::DEFAULT_DC_OFFSET_VALUE = std::complex<double>(0.0, 0.0);
 const std::complex<double> tx_frontend_core_200::DEFAULT_IQ_BALANCE_VALUE = std::complex<double>(0.0, 0.0);
 
+namespace {
+  static const double DC_OFFSET_MIN = -1.0;
+  static const double DC_OFFSET_MAX = 1.0;
+}
+
 static uint32_t fs_to_bits(const double num, const size_t bits){
     return int32_t(boost::math::round(num * (1 << (bits-1))));
 }
@@ -67,6 +73,9 @@ public:
 
     void populate_subtree(uhd::property_tree::sptr subtree)
     {
+        subtree->create<uhd::meta_range_t>("dc_offset/range")
+            .set(meta_range_t(DC_OFFSET_MIN, DC_OFFSET_MAX))
+        ;
         subtree->create< std::complex<double> >("dc_offset/value")
             .set(DEFAULT_DC_OFFSET_VALUE)
             .set_coercer(boost::bind(&tx_frontend_core_200::set_dc_offset, this, _1))
