@@ -1,18 +1,8 @@
 //
 // Copyright 2010-2012 Ettus Research LLC
+// Copyright 2018 Ettus Research, a National Instruments Company
 //
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
 //
 
 // IO Pin functions
@@ -40,7 +30,7 @@
 #include <uhd/utils/log.hpp>
 #include <uhd/utils/static.hpp>
 #include <uhd/utils/algorithm.hpp>
-#include <uhd/utils/msg.hpp>
+
 #include <uhd/usrp/dboard_id.hpp>
 #include <uhd/usrp/dboard_base.hpp>
 #include <uhd/usrp/dboard_manager.hpp>
@@ -184,7 +174,7 @@ rfx_xcvr::rfx_xcvr(
 
     this->get_rx_subtree()->create<sensor_value_t>("sensors/lo_locked")
         .set_publisher(boost::bind(&rfx_xcvr::get_locked, this, dboard_iface::UNIT_RX));
-    BOOST_FOREACH(const std::string &name, _rx_gain_ranges.keys()){
+    for(const std::string &name:  _rx_gain_ranges.keys()){
         this->get_rx_subtree()->create<double>("gains/"+name+"/value")
             .set_coercer(boost::bind(&rfx_xcvr::set_rx_gain, this, _1, name))
             .set(_rx_gain_ranges[name].start());
@@ -339,9 +329,9 @@ double rfx_xcvr::set_lo_freq(
     dboard_iface::unit_t unit,
     double target_freq
 ){
-    UHD_LOGV(often) << boost::format(
+    UHD_LOGGER_TRACE("RFX") << boost::format(
         "RFX tune: target frequency %f MHz"
-    ) % (target_freq/1e6) << std::endl;
+    ) % (target_freq/1e6) ;
 
     //clip the input
     target_freq = _freq_range.clip(target_freq);
@@ -369,7 +359,7 @@ double rfx_xcvr::set_lo_freq(
     int R=0, BS=0, P=0, B=0, A=0;
 
     /*
-     * The goal here to to loop though possible R dividers,
+     * The goal here to to loop through possible R dividers,
      * band select clock dividers, and prescaler values.
      * Calculate the A and B counters for each set of values.
      * The loop exits when it meets all of the constraints.
@@ -378,27 +368,34 @@ double rfx_xcvr::set_lo_freq(
      * fvco = [P*B + A] * fref/R
      * fvco*R/fref = P*B + A = N
      */
-    for(R = 2; R <= 32; R+=2){
-        BOOST_FOREACH(BS, bandsel_to_enum.keys()){
-            if (ref_freq/R/BS > 1e6) continue; //constraint on band select clock
-            BOOST_FOREACH(P, prescaler_to_enum.keys()){
-                //calculate B and A from N
-                double N = target_freq*R/ref_freq;
-                B = int(std::floor(N/P));
-                A = boost::math::iround(N - P*B);
-                if (B < A or B > 8191 or B < 3 or A > 31) continue; //constraints on A, B
-                //calculate the actual frequency
-                actual_freq = double(P*B + A)*ref_freq/R;
-                if (actual_freq/P > 300e6) continue; //constraint on prescaler output
-                //constraints met: exit loop
+    for (R = 2; R <= 32; R += 2) { // Search through all valid R values
+        for (BS = 1; BS <= 8; BS *= 2) { // Search through all valid band selects
+            if (ref_freq / R / BS > 1e6) {
+                continue; // constraint on band select clock
+            }
+            for (P = 8; P <= 32; P *= 2) { // Search through all prescaler values
+                // calculate B and A from N
+                double N = target_freq * R / ref_freq;
+                B        = int(std::floor(N / P));
+                A        = boost::math::iround(N - P * B);
+                if (B < A or B > 8191 or B < 3 or A > 31) {
+                    continue; // constraints on A, B
+                }
+                // calculate the actual frequency
+                actual_freq = double(P * B + A) * ref_freq / R;
+                if (actual_freq / P > 300e6) {
+                    continue; // constraint on prescaler output
+                }
+                // constraints met: exit loop
                 goto done_loop;
             }
         }
-    } done_loop:
+    }
+done_loop:
 
-    UHD_LOGV(often) << boost::format(
+    UHD_LOGGER_TRACE("RFX") << boost::format(
         "RFX tune: R=%d, BS=%d, P=%d, B=%d, A=%d, DIV2=%d"
-    ) % R % BS % P % B % A % int(_div2[unit] && (!is_rx_rfx400)) << std::endl;
+    ) % R % BS % P % B % A % int(_div2[unit] && (!is_rx_rfx400)) ;
 
     //load the register values
     adf4360_regs_t regs;
@@ -433,7 +430,7 @@ double rfx_xcvr::set_lo_freq(
         (adf4360_regs_t::ADDR_CONTROL)
         (adf4360_regs_t::ADDR_NCOUNTER)
     ;
-    BOOST_FOREACH(adf4360_regs_t::addr_t addr, addrs){
+    for(adf4360_regs_t::addr_t addr:  addrs){
         this->get_iface()->write_spi(
             unit, spi_config_t::EDGE_RISE,
             regs.get_reg(addr), 24
@@ -442,8 +439,8 @@ double rfx_xcvr::set_lo_freq(
 
     //return the actual frequency
     if (_div2[unit]) actual_freq /= 2;
-    UHD_LOGV(often) << boost::format(
+    UHD_LOGGER_TRACE("RFX") << boost::format(
         "RFX tune: actual frequency %f MHz"
-    ) % (actual_freq/1e6) << std::endl;
+    ) % (actual_freq/1e6) ;
     return actual_freq;
 }
