@@ -17,56 +17,27 @@ class magnesium_ad9371_iface
 public:
     using uptr = std::unique_ptr<magnesium_ad9371_iface>;
 
-    magnesium_ad9371_iface(
-        uhd::rpc_client::sptr rpcc,
-        const size_t slot_idx
-    );
+    magnesium_ad9371_iface(uhd::rpc_client::sptr rpcc, const size_t slot_idx);
 
     double set_frequency(
-        const double freq,
-        const size_t chan,
-        const uhd::direction_t dir
-    );
+        const double freq, const size_t chan, const uhd::direction_t dir);
 
-    double get_frequency(
-        const size_t chan,
-        const uhd::direction_t dir
-    );
+    double get_frequency(const size_t chan, const uhd::direction_t dir);
 
-    double set_gain(
-        const double gain,
-        const size_t chan,
-        const uhd::direction_t dir
-    );
+    double set_gain(const double gain, const size_t chan, const uhd::direction_t dir);
 
-    double get_gain(
-        const size_t chan,
-        const uhd::direction_t dir
-    );
+    double get_gain(const size_t chan, const uhd::direction_t dir);
 
-    double set_master_clock_rate(
-        const double freq
-    );
+    double set_master_clock_rate(const double freq);
 
     double set_bandwidth(
-        const double bandwidth,
-        const size_t chan,
-        const uhd::direction_t dir
-    );
+        const double bandwidth, const size_t chan, const uhd::direction_t dir);
 
-    double get_bandwidth(
-        const size_t chan,
-        const uhd::direction_t dir
-    );
+    double get_bandwidth(const size_t chan, const uhd::direction_t dir);
 
-    std::string set_lo_source(
-        const std::string &source,
-        const uhd::direction_t dir
-    );
+    std::string set_lo_source(const std::string& source, const uhd::direction_t dir);
 
-    std::string get_lo_source(
-        const uhd::direction_t dir
-    );
+    std::string get_lo_source(const uhd::direction_t dir);
 
 private:
     /*! Shorthand to perform an RPC request. Saves some typing.
@@ -76,6 +47,17 @@ private:
     {
         UHD_LOG_TRACE(_log_prefix, "[RPC] Calling " << func_name);
         return _rpcc->request_with_token<return_type>(
+            _rpc_prefix + func_name, std::forward<Args>(args)...);
+    };
+
+    /*! Shorthand to perform an RPC request with timeout.
+     */
+    template <typename return_type, typename... Args>
+    return_type request(uint64_t timeout_ms, std::string const& func_name, Args&&... args)
+    {
+        UHD_LOG_TRACE(_log_prefix, "[RPC] Calling " << func_name);
+        return _rpcc->request_with_token<return_type>(
+                timeout_ms,
                 _rpc_prefix + func_name,
                 std::forward<Args>(args)...
         );
@@ -92,8 +74,6 @@ private:
 
     //! Logger prefix
     const std::string _log_prefix;
-
 };
 
 #endif /* INCLUDED_LIBUHD_RFNOC_MAGNESIUM_AD9371_IFACE_HPP */
-// vim: sw=4 et:
