@@ -134,6 +134,8 @@ public:
             _lo2_iface[i]->set_output_power(adf435x_iface::OUTPUT_POWER_5DBM);
             _lo2_iface[i]->set_reference_freq(TWINRX_DESIRED_REFERENCE_FREQ);
             _lo2_iface[i]->set_muxout_mode(adf435x_iface::MUXOUT_DLD);
+            _lo2_iface[i]->set_tuning_mode(adf435x_iface::TUNING_MODE_LOW_SPUR);
+            _lo2_iface[i]->set_prescaler(adf435x_iface::PRESCALER_8_9);
         }
         commit();
     }
@@ -449,18 +451,13 @@ public:
     double set_lo2_synth_freq(channel_t ch, double freq, bool commit = true)
     {
         boost::lock_guard<boost::mutex> lock(_mutex);
-        static const double PRESCALER_THRESH = 3.6e9;
 
         double coerced_freq = 0.0;
         if (ch == CH1 or ch == BOTH) {
-            _lo2_iface[size_t(CH1)]->set_prescaler(freq > PRESCALER_THRESH ?
-                adf435x_iface::PRESCALER_8_9 : adf435x_iface::PRESCALER_4_5);
             coerced_freq = _lo2_iface[size_t(CH1)]->set_frequency(freq, false, false);
             _lo2_freq[size_t(CH1)] = tune_freq_t(freq);
         }
         if (ch == CH2 or ch == BOTH) {
-            _lo2_iface[size_t(CH2)]->set_prescaler(freq > PRESCALER_THRESH ?
-                adf435x_iface::PRESCALER_8_9 : adf435x_iface::PRESCALER_4_5);
             coerced_freq = _lo2_iface[size_t(CH2)]->set_frequency(freq, false, false);
             _lo2_freq[size_t(CH2)] = tune_freq_t(freq);
         }
@@ -469,6 +466,56 @@ public:
         return coerced_freq;
     }
 
+    double set_lo1_charge_pump(channel_t ch, double current, bool commit = true)
+    {
+        boost::lock_guard<boost::mutex> lock(_mutex);
+        double coerced_current = 0.0;
+        if (ch == CH1 or ch == BOTH) {
+            coerced_current =
+                _lo1_iface[size_t(CH1)]->set_charge_pump_current(current, false);
+        }
+        if (ch == CH2 or ch == BOTH) {
+            coerced_current =
+                _lo1_iface[size_t(CH2)]->set_charge_pump_current(current, false);
+        }
+
+        if (commit) {
+            _commit();
+        }
+        return coerced_current;
+    }
+
+    double set_lo2_charge_pump(channel_t ch, double current, bool commit = true)
+    {
+        boost::lock_guard<boost::mutex> lock(_mutex);
+        double coerced_current = 0.0;
+        if (ch == CH1 or ch == BOTH) {
+            coerced_current =
+                _lo2_iface[size_t(CH1)]->set_charge_pump_current(current, false);
+        }
+        if (ch == CH2 or ch == BOTH) {
+            coerced_current =
+                _lo2_iface[size_t(CH2)]->set_charge_pump_current(current, false);
+        }
+
+        if (commit) {
+            _commit();
+        }
+        return coerced_current;
+    }
+
+    uhd::meta_range_t get_lo1_charge_pump_range()
+    {
+        // assume that both channels have the same range
+        return _lo1_iface[size_t(CH1)]->get_charge_pump_current_range();
+    }
+
+    uhd::meta_range_t get_lo2_charge_pump_range()
+    {
+        // assume that both channels have the same range
+        return _lo2_iface[size_t(CH1)]->get_charge_pump_current_range();
+    }
+
     bool read_lo1_locked(channel_t ch)
     {
         boost::lock_guard<boost::mutex> lock(_mutex);
