@@ -1,23 +1,14 @@
 //
 // Copyright 2016 Ettus Research LLC
+// Copyright 2018 Ettus Research, a National Instruments Company
 //
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
 //
 
 #include "twinrx_experts.hpp"
 #include "twinrx_gain_tables.hpp"
 #include <uhd/utils/math.hpp>
+#include <uhd/utils/log.hpp>
 #include <uhd/exception.hpp>
 #include <uhd/types/dict.hpp>
 #include <uhd/types/ranges.hpp>
@@ -486,7 +477,7 @@ void twinrx_ant_gain_expert::resolve()
             (_ch0_preamp2 != _ch1_preamp2) or
             (_ch0_lb_preamp_presel != _ch1_lb_preamp_presel))
         {
-            UHD_MSG(warning) << "incompatible gain settings for antenna sharing. temporarily using Ch0 settings for Ch1.";
+            UHD_LOGGER_WARNING("TWINRX") << "incompatible gain settings for antenna sharing. temporarily using Ch0 settings for Ch1.";
         }
         _ant0_input_atten       = _ch0_input_atten;
         _ant0_preamp1           = _ch0_preamp1;
@@ -504,7 +495,7 @@ void twinrx_ant_gain_expert::resolve()
             (_ch0_preamp2 != _ch1_preamp2) or
             (_ch0_lb_preamp_presel != _ch1_lb_preamp_presel))
         {
-            UHD_MSG(warning) << "incompatible gain settings for antenna sharing. temporarily using Ch0 settings for Ch1.";
+            UHD_LOGGER_WARNING("TWINRX") << "incompatible gain settings for antenna sharing. temporarily using Ch0 settings for Ch1.";
         }
         _ant1_input_atten       = _ch0_input_atten;
         _ant1_preamp1           = _ch0_preamp1;
@@ -552,6 +543,10 @@ void twinrx_settings_expert::resolve()
         _ctrl->set_hb_atten(ch, ch_set.hb_atten, FORCE_COMMIT);
         _ctrl->set_lo1_source(ch, ch_set.lo1_source, FORCE_COMMIT);
         _ctrl->set_lo2_source(ch, ch_set.lo2_source, FORCE_COMMIT);
+        ch_set.lo1_charge_pump_c =
+            _ctrl->set_lo1_charge_pump(ch, ch_set.lo1_charge_pump_d, FORCE_COMMIT);
+        ch_set.lo2_charge_pump_c =
+            _ctrl->set_lo2_charge_pump(ch, ch_set.lo2_charge_pump_d, FORCE_COMMIT);
     }
 
     _resolve_lox_freq(STAGE_LO1,
