@@ -1,24 +1,12 @@
 //
 // Copyright 2015 Ettus Research LLC
+// Copyright 2018 Ettus Research, a National Instruments Company
 //
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
 //
 
 #include <uhd/usrp/dboard_eeprom.h>
 #include <uhd/error.h>
-
-#include <boost/lexical_cast.hpp>
 #include <boost/format.hpp>
 
 #include <string.h>
@@ -86,8 +74,13 @@ uhd_error uhd_dboard_eeprom_set_serial(
 int _convert_rev_with_exception(const std::string &rev_str)
 {
     try {
-        return boost::lexical_cast<int>(rev_str);
-    } catch (const boost::bad_lexical_cast &) {
+        return std::stoi(rev_str);
+    } catch (const std::invalid_argument &) {
+        throw uhd::lookup_error(str(
+            boost::format("Error retrieving revision from string `%s`")
+            % rev_str
+        ));
+    } catch (const std::out_of_range &) {
         throw uhd::lookup_error(str(
             boost::format("Error retrieving revision from string `%s`")
             % rev_str
@@ -110,7 +103,7 @@ uhd_error uhd_dboard_eeprom_set_revision(
     int revision
 ){
     UHD_SAFE_C_SAVE_ERROR(h,
-        h->dboard_eeprom_cpp.revision = boost::lexical_cast<std::string>(revision);
+        h->dboard_eeprom_cpp.revision = std::to_string(revision);
     )
 }
 
