@@ -1,30 +1,20 @@
 //
 // Copyright 2013-2014 Ettus Research LLC
+// Copyright 2018 Ettus Research, a National Instruments Company
 //
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
 //
 
 #ifndef INCLUDED_N230_CORES_HPP
 #define INCLUDED_N230_CORES_HPP
 
-#include "spi_core_3000.hpp"
-#include "adf4001_ctrl.hpp"
+#include <uhdlib/usrp/cores/spi_core_3000.hpp>
+#include <uhdlib/usrp/common/adf4001_ctrl.hpp>
 #include <boost/thread/mutex.hpp>
 
 namespace uhd { namespace usrp { namespace n230 {
 
-class n230_core_spi_core : boost::noncopyable, public uhd::spi_iface {
+class n230_core_spi_core : uhd::noncopyable, public uhd::spi_iface {
 
 public:
     typedef boost::shared_ptr<n230_core_spi_core> sptr;
