@@ -1,37 +1,26 @@
 //
 // Copyright 2013 Ettus Research LLC
+// Copyright 2018 Ettus Research, a National Instruments Company
 //
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
 //
 
 #include "n230_resource_manager.hpp"
 
-#include "usrp3_fw_ctrl_iface.hpp"
+#include "n230_fw_ctrl_iface.hpp"
 #include <uhd/transport/if_addrs.hpp>
 #include <uhd/transport/udp_zero_copy.hpp>
 #include <uhd/utils/byteswap.hpp>
-#include <uhd/utils/msg.hpp>
+#include <uhd/utils/log.hpp>
 #include <uhd/utils/platform.hpp>
 #include <uhd/utils/paths.hpp>
 #include <boost/format.hpp>
-#include <boost/thread.hpp>
-#include <boost/lexical_cast.hpp>
 #include <boost/functional/hash.hpp>
-#include <boost/lexical_cast.hpp>
 #include <boost/make_shared.hpp>
 #include "n230_fw_defs.h"
 #include "n230_fw_host_iface.h"
+#include <chrono>
+#include <thread>
 
 #define IF_DATA_I_MASK  0xFFF00000
 #define IF_DATA_Q_MASK  0x0000FFF0
@@ -46,6 +35,8 @@ static const uint8_t N230_HOST_DEST_ADDR     = 2;
 static const uint8_t N230_ETH0_IFACE_ID  = 0;
 static const uint8_t N230_ETH1_IFACE_ID  = 1;
 
+boost::mutex n230_resource_manager::_claimer_mutex;
+
 class n230_ad9361_client_t : public ad9361_params {
 public:
     ~n230_ad9361_client_t() {}
@@ -58,7 +49,7 @@ public:
         }
     }
     clocking_mode_t get_clocking_mode() {
-        return AD9361_XTAL_N_CLK_PATH;
+        return clocking_mode_t::AD9361_XTAL_N_CLK_PATH;
     }
     digital_interface_mode_t get_digital_interface_mode() {
         return AD9361_DDR_FDD_LVDS;
@@ -80,18 +71,18 @@ n230_resource_manager::n230_resource_manager(
     _safe_mode(safe_mode),
     _last_host_enpoint(0)
 {
-    if (_safe_mode) UHD_MSG(warning) << "Initializing device in safe mode\n";
-    UHD_MSG(status) << "Setup basic communication...\n";
+    if (_safe_mode) UHD_LOGGER_WARNING("N230") << "Initializing device in safe mode\n";
+    UHD_LOGGER_INFO("N230") << "Setup basic communication...";
 
     //Discover ethernet interfaces
     bool dual_eth_expected = (ip_addrs.size() > 1);
-    BOOST_FOREACH(const std::string& addr, ip_addrs) {
+    for(const std::string& addr:  ip_addrs) {
         n230_eth_conn_t conn_iface;
         conn_iface.ip_addr = addr;
 
         uint32_t iface_id = 0xFFFFFFFF;
         try {
-            iface_id = usrp3::usrp3_fw_ctrl_iface::get_iface_id(
+            iface_id = n230::n230_fw_ctrl_iface::get_iface_id(
                 conn_iface.ip_addr, BOOST_STRINGIZE(N230_FW_COMMS_UDP_PORT), N230_FW_PRODUCT_ID);
         } catch (uhd::io_error&) {
             throw uhd::io_error(str(boost::format(
@@ -118,7 +109,7 @@ n230_resource_manager::n230_resource_manager(
     }
 
     //Create firmware communication interface
-    _fw_ctrl = usrp3::usrp3_fw_ctrl_iface::make(
+    _fw_ctrl = n230::n230_fw_ctrl_iface::make(
         transport::udp_simple::make_connected(
             _get_conn(PRI_ETH).ip_addr, BOOST_STRINGIZE(N230_FW_COMMS_UDP_PORT)), N230_FW_PRODUCT_ID);
     if (_fw_ctrl.get() == NULL) {
@@ -145,7 +136,7 @@ n230_resource_manager::n230_resource_manager(
     }
     _check_fpga_compat();
 
-    UHD_MSG(status) << boost::format("Version signatures... Firmware:%s FPGA:%s...\n")
+    UHD_LOGGER_INFO("N230") << boost::format("Version signatures... Firmware:%s FPGA:%s...")
         % _fw_version.get_hash_str() % _fpga_version.get_hash_str();
 
     _core_radio_ctrl_reg.initialize(*_core_ctrl, true /*flush*/);
@@ -160,7 +151,7 @@ n230_resource_manager::n230_resource_manager(
     }
 
     //Create AD9361 interface
-    UHD_MSG(status) << "Initializing CODEC...\n";
+    UHD_LOGGER_INFO("N230") << "Initializing CODEC...";
     _codec_ctrl = ad9361_ctrl::make_spi(
         boost::make_shared<n230_ad9361_client_t>(), _core_spi_ctrl, fpga::AD9361_SPI_SLAVE_NUM);
     if (_codec_ctrl.get() == NULL) {
@@ -210,7 +201,7 @@ n230_resource_manager::n230_resource_manager(
 
     //Create GPSDO interface
     if (_core_status_reg.read(fpga::core_status_reg_t::GPSDO_STATUS) != fpga::GPSDO_ST_ABSENT) {
-        UHD_MSG(status) << "Detecting GPSDO.... " << std::flush;
+        UHD_LOGGER_INFO("N230") << "Detecting GPSDO.... ";
         try {
             const sid_t gps_uart_sid = _generate_sid(GPS_UART, _get_conn(PRI_ETH).type);
             transport::zero_copy_if::sptr gps_uart_xport =
@@ -218,10 +209,10 @@ n230_resource_manager::n230_resource_manager(
             _gps_uart = n230_uart::make(gps_uart_xport, uhd::htonx(gps_uart_sid.get()));
             _gps_uart->set_baud_divider(fpga::BUS_CLK_RATE/fpga::GPSDO_UART_BAUDRATE);
             _gps_uart->write_uart("\n"); //cause the baud and response to be setup
-            boost::this_thread::sleep(boost::posix_time::seconds(1)); //allow for a little propagation
+            std::this_thread::sleep_for(std::chrono::seconds(1)); //allow for a little propagation
             _gps_ctrl = gps_ctrl::make(_gps_uart);
         } catch(std::exception &e) {
-            UHD_MSG(error) << "An error occurred making GPSDO control: " << e.what() << std::endl;
+            UHD_LOGGER_ERROR("N230") << "An error occurred making GPSDO control: " << e.what() ;
         }
         if (not is_gpsdo_present()) {
             _core_ctrl->poke32(fpga::sr_addr(fpga::SR_CORE_GPSDO_ST), fpga::GPSDO_ST_ABSENT);
@@ -251,7 +242,7 @@ n230_resource_manager::~n230_resource_manager()
 {
     _claimer_task.reset();
     {   //Critical section
-        boost::mutex::scoped_lock(_claimer_mutex);
+        boost::mutex::scoped_lock lock(_claimer_mutex);
         _fw_ctrl->poke32(N230_FW_HOST_SHMEM_OFFSET(claim_time), 0);
         _fw_ctrl->poke32(N230_FW_HOST_SHMEM_OFFSET(claim_src), 0);
     }
@@ -276,9 +267,9 @@ transport::zero_copy_if::sptr n230_resource_manager::create_transport(
     return xport;
 }
 
-bool n230_resource_manager::is_device_claimed(uhd::usrp::usrp3::usrp3_fw_ctrl_iface::sptr fw_ctrl)
+bool n230_resource_manager::is_device_claimed(n230_fw_ctrl_iface::sptr fw_ctrl)
 {
-    boost::mutex::scoped_lock(_claimer_mutex);
+    boost::mutex::scoped_lock lock(_claimer_mutex);
 
     //If timed out then device is definitely unclaimed
     if (fw_ctrl->peek32(N230_FW_HOST_SHMEM_OFFSET(claim_status)) == 0)
@@ -291,11 +282,11 @@ bool n230_resource_manager::is_device_claimed(uhd::usrp::usrp3::usrp3_fw_ctrl_if
 void n230_resource_manager::_claimer_loop()
 {
     {   //Critical section
-        boost::mutex::scoped_lock(_claimer_mutex);
+        boost::mutex::scoped_lock lock(_claimer_mutex);
         _fw_ctrl->poke32(N230_FW_HOST_SHMEM_OFFSET(claim_time), time(NULL));
         _fw_ctrl->poke32(N230_FW_HOST_SHMEM_OFFSET(claim_src), get_process_hash());
     }
-    boost::this_thread::sleep(boost::posix_time::milliseconds(N230_CLAIMER_TIMEOUT_IN_MS / 2));
+    std::this_thread::sleep_for(std::chrono::milliseconds(N230_CLAIMER_TIMEOUT_IN_MS / 2));
 }
 
 void n230_resource_manager::_initialize_radio(size_t instance)
@@ -419,7 +410,7 @@ transport::zero_copy_if::sptr n230_resource_manager::_create_transport(
     default_buff_args.num_send_frames = 32;
 
     transport::zero_copy_if::sptr xport = transport::udp_zero_copy::make(
-        eth_conn.ip_addr, boost::lexical_cast<std::string>(fpga::CVITA_UDP_PORT),
+        eth_conn.ip_addr, std::to_string(fpga::CVITA_UDP_PORT),
         default_buff_args, buff_params_out, buff_params);
 
     if (xport.get()) {
@@ -456,7 +447,7 @@ void n230_resource_manager::_reset_codec_digital_interface()
     _core_ctrl->poke32(fpga::sr_addr(fpga::SR_CORE_CLK_DELAY), fpga::CODEC_CLK_DELAY);
 
     _core_radio_ctrl_reg.write(fpga::core_radio_ctrl_reg_t::CODEC_ARST, 1);
-    boost::this_thread::sleep(boost::posix_time::milliseconds(10));
+    std::this_thread::sleep_for(std::chrono::milliseconds(10));
     _core_radio_ctrl_reg.write(fpga::core_radio_ctrl_reg_t::CODEC_ARST, 0);
 }
 
@@ -482,13 +473,13 @@ bool n230_resource_manager::_radio_data_loopback_self_test(wb_iface::sptr iface)
         const uint32_t word32 = uint32_t(hash) & (IF_DATA_I_MASK | IF_DATA_Q_MASK);
         iface->poke32(fpga::sr_addr(fpga::SR_RADIO_CODEC_IDLE), word32);
         iface->peek64(fpga::rb_addr(fpga::RB_RADIO_CODEC_DATA)); //block until request completes
-        boost::this_thread::sleep(boost::posix_time::microseconds(100)); //wait for loopback to propagate through codec
+        std::this_thread::sleep_for(std::chrono::microseconds(100)); //wait for loopback to propagate through codec
         const uint64_t rb_word64 = iface->peek64(fpga::rb_addr(fpga::RB_RADIO_CODEC_DATA));
         const uint32_t rb_tx = uint32_t(rb_word64 >> 32);
         const uint32_t rb_rx = uint32_t(rb_word64 & 0xffffffff);
         test_fail = word32 != rb_tx or word32 != rb_rx;
         if (test_fail){
-            UHD_MSG(fastpath) << boost::format("mismatch (exp:%x, got:%x and %x)... ") % word32 % rb_tx % rb_rx;
+            UHD_LOG_ERROR("N230", str(boost::format("mismatch (exp:%x, got:%x and %x)... ") % word32 % rb_tx % rb_rx));
             break; //exit loop on any failure
         }
     }
