@@ -1,48 +1,40 @@
 //
 // Copyright 2010-2012,2014 Ettus Research LLC
+// Copyright 2018 Ettus Research, a National Instruments Company
 //
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
 //
 
 #include "usrp1_impl.hpp"
 #include <uhd/utils/log.hpp>
 #include <uhd/utils/safe_call.hpp>
 #include <uhd/transport/usb_control.hpp>
-#include <uhd/utils/msg.hpp>
+#include <uhd/utils/log.hpp>
 #include <uhd/utils/cast.hpp>
 #include <uhd/exception.hpp>
 #include <uhd/utils/static.hpp>
 #include <uhd/utils/paths.hpp>
 #include <boost/format.hpp>
-#include <boost/assign/list_of.hpp>
 #include <boost/filesystem.hpp>
-#include <boost/thread/thread.hpp>
 #include <boost/lexical_cast.hpp>
 #include <boost/math/special_functions/round.hpp>
 #include <cstdio>
+#include <chrono>
 
 using namespace uhd;
 using namespace uhd::usrp;
 using namespace uhd::transport;
 
-const uint16_t USRP1_VENDOR_ID  = 0xfffe;
-const uint16_t USRP1_PRODUCT_ID = 0x0002;
-static const boost::posix_time::milliseconds REENUMERATION_TIMEOUT_MS(3000);
+namespace {
+    constexpr uint16_t USRP1_VENDOR_ID  = 0xfffe;
+    constexpr uint16_t USRP1_PRODUCT_ID = 0x0002;
+    constexpr int64_t  REENUMERATION_TIMEOUT_MS = 3000;
+}
 
-const std::vector<usrp1_impl::dboard_slot_t> usrp1_impl::_dboard_slots = boost::assign::list_of
-    (usrp1_impl::DBOARD_SLOT_A)(usrp1_impl::DBOARD_SLOT_B)
-;
+const std::vector<usrp1_impl::dboard_slot_t> usrp1_impl::_dboard_slots{
+    usrp1_impl::DBOARD_SLOT_A,
+    usrp1_impl::DBOARD_SLOT_B
+};
 
 /***********************************************************************
  * Discovery
@@ -76,16 +68,16 @@ static device_addrs_t usrp1_find(const device_addr_t &hint)
 
     //find the usrps and load firmware
     size_t found = 0;
-    BOOST_FOREACH(usb_device_handle::sptr handle, usb_device_handle::get_device_list(vid, pid)) {
+    for(usb_device_handle::sptr handle: usb_device_handle::get_device_list(vid,  pid)) {
         //extract the firmware path for the USRP1
         std::string usrp1_fw_image;
         try{
             usrp1_fw_image = find_image_path(hint.get("fw", "usrp1_fw.ihx"));
         }
         catch(...){
-            UHD_MSG(warning) << boost::format("Could not locate USRP1 firmware. %s") % print_utility_error("uhd_images_downloader.py");
+            UHD_LOGGER_WARNING("USRP1") << boost::format("Could not locate USRP1 firmware. %s") % print_utility_error("uhd_images_downloader.py");
         }
-        UHD_LOG << "USRP1 firmware image: " << usrp1_fw_image << std::endl;
+        UHD_LOGGER_DEBUG("USRP1") << "USRP1 firmware image: " << usrp1_fw_image ;
 
         usb_control::sptr control;
         try{control = usb_control::make(handle, 0);}
@@ -99,19 +91,21 @@ static device_addrs_t usrp1_find(const device_addr_t &hint)
     vid = USRP1_VENDOR_ID;
     pid = USRP1_PRODUCT_ID;
 
-    const boost::system_time timeout_time = boost::get_system_time() + REENUMERATION_TIMEOUT_MS;
+    const auto timeout_time =
+        std::chrono::steady_clock::now()
+        + std::chrono::milliseconds(REENUMERATION_TIMEOUT_MS);
 
     //search for the device until found or timeout
-    while (boost::get_system_time() < timeout_time and usrp1_addrs.empty() and found != 0)
-    {
-        BOOST_FOREACH(usb_device_handle::sptr handle, usb_device_handle::get_device_list(vid, pid))
-        {
+    while (std::chrono::steady_clock::now() < timeout_time
+            and usrp1_addrs.empty() and found != 0) {
+        for (usb_device_handle::sptr handle : usb_device_handle::get_device_list(vid, pid)) {
             usb_control::sptr control;
             try{control = usb_control::make(handle, 0);}
             catch(const uhd::exception &){continue;} //ignore claimed
 
             fx2_ctrl::sptr fx2_ctrl = fx2_ctrl::make(control);
-            const mboard_eeprom_t mb_eeprom(*fx2_ctrl, USRP1_EEPROM_MAP_KEY);
+            const mboard_eeprom_t mb_eeprom =
+                usrp1_impl::get_mb_eeprom(fx2_ctrl);
             device_addr_t new_addr;
             new_addr["type"] = "usrp1";
             new_addr["name"] = mb_eeprom["name"];
@@ -144,14 +138,14 @@ UHD_STATIC_BLOCK(register_usrp1_device){
  * Structors
  **********************************************************************/
 usrp1_impl::usrp1_impl(const device_addr_t &device_addr){
-    UHD_MSG(status) << "Opening a USRP1 device..." << std::endl;
+    UHD_LOGGER_INFO("USRP1") << "Opening a USRP1 device...";
     _type = device::USRP;
 
     //extract the FPGA path for the USRP1
     std::string usrp1_fpga_image = find_image_path(
         device_addr.get("fpga", "usrp1_fpga.rbf")
     );
-    UHD_LOG << "USRP1 FPGA image: " << usrp1_fpga_image << std::endl;
+    UHD_LOGGER_DEBUG("USRP1") << "USRP1 FPGA image: " << usrp1_fpga_image ;
 
     //try to match the given device address with something on the USB bus
     std::vector<usb_device_handle::sptr> device_list =
@@ -159,7 +153,7 @@ usrp1_impl::usrp1_impl(const device_addr_t &device_addr){
 
     //locate the matching handle in the device list
     usb_device_handle::sptr handle;
-    BOOST_FOREACH(usb_device_handle::sptr dev_handle, device_list) {
+    for(usb_device_handle::sptr dev_handle:  device_list) {
         if (dev_handle->get_serial() == device_addr["serial"]){
             handle = dev_handle;
             break;
@@ -190,12 +184,12 @@ usrp1_impl::usrp1_impl(const device_addr_t &device_addr){
     _iface->poke32(FR_MODE, 0x00000000);
     _iface->poke32(FR_DEBUG_EN, 0x00000000);
 
-    UHD_LOG
-        << "USRP1 Capabilities" << std::endl
-        << "    number of duc's: " << get_num_ddcs() << std::endl
-        << "    number of ddc's: " << get_num_ducs() << std::endl
-        << "    rx halfband:     " << has_rx_halfband() << std::endl
-        << "    tx halfband:     " << has_tx_halfband() << std::endl
+    UHD_LOGGER_DEBUG("USRP1")
+        << "USRP1 Capabilities" 
+        << "    number of duc's: " << get_num_ddcs() 
+        << "    number of ddc's: " << get_num_ducs() 
+        << "    rx halfband:     " << has_rx_halfband() 
+        << "    tx halfband:     " << has_tx_halfband() 
     ;
 
     ////////////////////////////////////////////////////////////////////
@@ -218,7 +212,8 @@ usrp1_impl::usrp1_impl(const device_addr_t &device_addr){
     ////////////////////////////////////////////////////////////////////
     // setup the mboard eeprom
     ////////////////////////////////////////////////////////////////////
-    const mboard_eeprom_t mb_eeprom(*_fx2_ctrl, USRP1_EEPROM_MAP_KEY);
+    //const mboard_eeprom_t mb_eeprom(*_fx2_ctrl, USRP1_EEPROM_MAP_KEY);
+    const mboard_eeprom_t mb_eeprom = this->get_mb_eeprom(_fx2_ctrl);
     _tree->create<mboard_eeprom_t>(mb_path / "eeprom")
         .set(mb_eeprom)
         .add_coerced_subscriber(boost::bind(&usrp1_impl::set_mb_eeprom, this, _1));
@@ -229,21 +224,21 @@ usrp1_impl::usrp1_impl(const device_addr_t &device_addr){
     _master_clock_rate = 64e6;
     if (device_addr.has_key("mcr")){
         try{
-            _master_clock_rate = boost::lexical_cast<double>(device_addr["mcr"]);
+            _master_clock_rate = std::stod(device_addr["mcr"]);
         }
         catch(const std::exception &e){
-            UHD_MSG(error) << "Error parsing FPGA clock rate from device address: " << e.what() << std::endl;
+            UHD_LOGGER_ERROR("USRP1") << "Error parsing FPGA clock rate from device address: " << e.what() ;
         }
     }
     else if (not mb_eeprom["mcr"].empty()){
         try{
-            _master_clock_rate = boost::lexical_cast<double>(mb_eeprom["mcr"]);
+            _master_clock_rate = std::stod(mb_eeprom["mcr"]);
         }
         catch(const std::exception &e){
-            UHD_MSG(error) << "Error parsing FPGA clock rate from EEPROM: " << e.what() << std::endl;
+            UHD_LOGGER_ERROR("USRP1") << "Error parsing FPGA clock rate from EEPROM: " << e.what() ;
         }
     }
-    UHD_MSG(status) << boost::format("Using FPGA clock rate of %fMHz...") % (_master_clock_rate/1e6) << std::endl;
+    UHD_LOGGER_INFO("USRP1") << boost::format("Using FPGA clock rate of %fMHz...") % (_master_clock_rate/1e6) ;
     _tree->create<double>(mb_path / "tick_rate")
         .add_coerced_subscriber(boost::bind(&usrp1_impl::update_tick_rate, this, _1))
         .set(_master_clock_rate);
@@ -251,7 +246,7 @@ usrp1_impl::usrp1_impl(const device_addr_t &device_addr){
     ////////////////////////////////////////////////////////////////////
     // create codec control objects
     ////////////////////////////////////////////////////////////////////
-    BOOST_FOREACH(const std::string &db, _dbc.keys()){
+    for(const std::string &db:  _dbc.keys()){
         _dbc[db].codec = usrp1_codec_ctrl::make(_iface, (db == "A")? SPI_ENABLE_CODEC_A : SPI_ENABLE_CODEC_B);
         const fs_path rx_codec_path = mb_path / "rx_codecs" / db;
         const fs_path tx_codec_path = mb_path / "tx_codecs" / db;
@@ -284,7 +279,7 @@ usrp1_impl::usrp1_impl(const device_addr_t &device_addr){
         .set(subdev_spec_t())
         .add_coerced_subscriber(boost::bind(&usrp1_impl::update_tx_subdev_spec, this, _1));
 
-    BOOST_FOREACH(const std::string &db, _dbc.keys()){
+    for(const std::string &db:  _dbc.keys()){
         const fs_path rx_fe_path = mb_path / "rx_frontends" / db;
         _tree->create<std::complex<double> >(rx_fe_path / "dc_offset" / "value")
             .set_coercer(boost::bind(&usrp1_impl::set_rx_dc_offset, this, db, _1))
@@ -349,7 +344,7 @@ usrp1_impl::usrp1_impl(const device_addr_t &device_addr){
     ////////////////////////////////////////////////////////////////////
     // create dboard control objects
     ////////////////////////////////////////////////////////////////////
-    BOOST_FOREACH(const std::string &db, _dbc.keys()){
+    for(const std::string &db:  _dbc.keys()){
 
         //read the dboard eeprom to extract the dboard ids
         dboard_eeprom_t rx_db_eeprom, tx_db_eeprom, gdb_eeprom;
@@ -400,7 +395,7 @@ usrp1_impl::usrp1_impl(const device_addr_t &device_addr){
     this->update_rates();
 
     //reset cordic rates and their properties to zero
-    BOOST_FOREACH(const std::string &name, _tree->list(mb_path / "rx_dsps")){
+    for(const std::string &name:  _tree->list(mb_path / "rx_dsps")){
         _tree->access<double>(mb_path / "rx_dsps" / name / "freq" / "value").set(0.0);
     }
 
@@ -452,10 +447,6 @@ bool usrp1_impl::has_tx_halfband(void){
 /***********************************************************************
  * Properties callback methods below
  **********************************************************************/
-void usrp1_impl::set_mb_eeprom(const uhd::usrp::mboard_eeprom_t &mb_eeprom){
-    mb_eeprom.commit(*_fx2_ctrl, USRP1_EEPROM_MAP_KEY);
-}
-
 void usrp1_impl::set_db_eeprom(const std::string &db, const std::string &type, const uhd::usrp::dboard_eeprom_t &db_eeprom){
     if (type == "rx") db_eeprom.store(*_fx2_ctrl, (db == "A")? (I2C_ADDR_RX_A) : (I2C_ADDR_RX_B));
     if (type == "tx") db_eeprom.store(*_fx2_ctrl, (db == "A")? (I2C_ADDR_TX_A) : (I2C_ADDR_TX_B));
