@@ -1,18 +1,8 @@
 //
 // Copyright 2010-2012,2014 Ettus Research LLC
+// Copyright 2018 Ettus Research, a National Instruments Company
 //
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
 //
 
 #ifndef INCLUDED_CODEC_CTRL_HPP
@@ -20,9 +10,9 @@
 
 #include "usrp2_iface.hpp"
 #include <boost/shared_ptr.hpp>
-#include <boost/utility.hpp>
+#include <uhd/utils/noncopyable.hpp>
 
-class usrp2_codec_ctrl : boost::noncopyable{
+class usrp2_codec_ctrl : uhd::noncopyable{
 public:
     typedef boost::shared_ptr<usrp2_codec_ctrl> sptr;
 
@@ -66,6 +56,13 @@ public:
 
     virtual void set_rx_digital_fine_gain(double gain) = 0;
 
+    /*! Return the internal interpolation on the TX side. This is the factor
+     *  between the rate of incoming samples and rate at which the DAC is
+     *  actually clocked. Values > 1 will enable features, such as internal
+     *  modulation.
+     */
+    virtual size_t get_tx_interpolation() const = 0;
+
 };
 
 #endif /* INCLUDED_CODEC_CTRL_HPP */
