@@ -1,18 +1,8 @@
 //
 // Copyright 2015-2016 Ettus Research LLC
+// Copyright 2018 Ettus Research, a National Instruments Company
 //
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
 //
 
 #include <cstring>
@@ -225,7 +215,7 @@ static uhd::device_addr_t n200_find(const image_loader::image_loader_args_t &ima
          * this query. If the user supplied specific arguments that
          * led to a USRP2, throw an error.
          */
-        BOOST_FOREACH(const uhd::device_addr_t &dev, found){
+        for(const uhd::device_addr_t &dev:  found){
             rev_xport = udp_simple::make_connected(
                             dev.get("addr"),
                             BOOST_STRINGIZE(N200_UDP_FW_UPDATE_PORT)
@@ -257,7 +247,7 @@ static uhd::device_addr_t n200_find(const image_loader::image_loader_args_t &ima
             std::string err_msg = "Could not resolve given args to a single N-Series device.\n"
                                   "Applicable devices:\n";
 
-            BOOST_FOREACH(const uhd::device_addr_t &dev, n200_found){
+            for(const uhd::device_addr_t &dev:  n200_found){
                 err_msg += str(boost::format("* %s (addr=%s)\n")
                                % dev.get("hw_rev")
                                % dev.get("addr"));
