@@ -435,7 +435,7 @@ uhd_error uhd_usrp_get_mboard_name(
 uhd_error uhd_usrp_get_time_now(
     uhd_usrp_handle h,
     size_t mboard,
-    time_t *full_secs_out,
+    int64_t *full_secs_out,
     double *frac_secs_out
 ){
     UHD_SAFE_C_SAVE_ERROR(h,
@@ -448,7 +448,7 @@ uhd_error uhd_usrp_get_time_now(
 uhd_error uhd_usrp_get_time_last_pps(
     uhd_usrp_handle h,
     size_t mboard,
-    time_t *full_secs_out,
+    int64_t *full_secs_out,
     double *frac_secs_out
 ){
     UHD_SAFE_C_SAVE_ERROR(h,
@@ -460,7 +460,7 @@ uhd_error uhd_usrp_get_time_last_pps(
 
 uhd_error uhd_usrp_set_time_now(
     uhd_usrp_handle h,
-    time_t full_secs,
+    int64_t full_secs,
     double frac_secs,
     size_t mboard
 ){
@@ -472,7 +472,7 @@ uhd_error uhd_usrp_set_time_now(
 
 uhd_error uhd_usrp_set_time_next_pps(
     uhd_usrp_handle h,
-    time_t full_secs,
+    int64_t full_secs,
     double frac_secs,
     size_t mboard
 ){
@@ -484,7 +484,7 @@ uhd_error uhd_usrp_set_time_next_pps(
 
 uhd_error uhd_usrp_set_time_unknown_pps(
     uhd_usrp_handle h,
-    time_t full_secs,
+    int64_t full_secs,
     double frac_secs
 ){
     UHD_SAFE_C_SAVE_ERROR(h,
@@ -505,7 +505,7 @@ uhd_error uhd_usrp_get_time_synchronized(
 
 uhd_error uhd_usrp_set_command_time(
     uhd_usrp_handle h,
-    time_t full_secs,
+    int64_t full_secs,
     double frac_secs,
     size_t mboard
 ){
@@ -1227,6 +1227,95 @@ uhd_error uhd_usrp_get_fe_tx_freq_range(
     )
 }
 
+UHD_API uhd_error uhd_usrp_get_tx_lo_names(
+    uhd_usrp_handle h,
+    size_t chan,
+    uhd_string_vector_handle *tx_lo_names_out
+){
+    UHD_SAFE_C_SAVE_ERROR(h,
+        (*tx_lo_names_out)->string_vector_cpp = USRP(h)->get_tx_lo_names(chan);
+    )
+}
+
+UHD_API uhd_error uhd_usrp_set_tx_lo_source(
+    uhd_usrp_handle h,
+    const char* src,
+    const char* name,
+    size_t chan
+){
+    UHD_SAFE_C_SAVE_ERROR(h,
+        USRP(h)->set_tx_lo_source(src, name, chan);
+    )
+}
+
+UHD_API uhd_error uhd_usrp_get_tx_lo_source(
+    uhd_usrp_handle h,
+    const char* name,
+    size_t chan,
+    char* tx_lo_source_out,
+    size_t strbuffer_len
+){
+    UHD_SAFE_C_SAVE_ERROR(h,
+        strncpy(tx_lo_source_out, USRP(h)->get_tx_lo_source(name, chan).c_str(), strbuffer_len);
+    )
+}
+
+UHD_API uhd_error uhd_usrp_get_tx_lo_sources(
+    uhd_usrp_handle h,
+    const char* name,
+    size_t chan,
+    uhd_string_vector_handle *tx_lo_sources_out
+){
+    UHD_SAFE_C_SAVE_ERROR(h,
+        (*tx_lo_sources_out)->string_vector_cpp = USRP(h)->get_tx_lo_sources(name, chan);
+    )
+}
+
+UHD_API uhd_error uhd_usrp_set_tx_lo_export_enabled(
+    uhd_usrp_handle h,
+    bool enabled,
+    const char* name,
+    size_t chan
+){
+    UHD_SAFE_C_SAVE_ERROR(h,
+        USRP(h)->set_tx_lo_export_enabled(enabled, name, chan);
+    )
+}
+
+UHD_API uhd_error uhd_usrp_get_tx_lo_export_enabled(
+    uhd_usrp_handle h,
+    const char* name,
+    size_t chan,
+    bool* result_out
+) {
+    UHD_SAFE_C_SAVE_ERROR(h,
+        *result_out = USRP(h)->get_tx_lo_export_enabled(name, chan);
+    )
+}
+
+UHD_API uhd_error uhd_usrp_set_tx_lo_freq(
+    uhd_usrp_handle h,
+    double freq,
+    const char* name,
+    size_t chan,
+    double* coerced_freq_out
+){
+    UHD_SAFE_C_SAVE_ERROR(h,
+        *coerced_freq_out = USRP(h)->set_tx_lo_freq(freq, name, chan);
+    )
+}
+
+UHD_API uhd_error uhd_usrp_get_tx_lo_freq(
+    uhd_usrp_handle h,
+    const char* name,
+    size_t chan,
+    double* tx_lo_freq_out
+){
+    UHD_SAFE_C_SAVE_ERROR(h,
+        *tx_lo_freq_out = USRP(h)->get_tx_lo_freq(name, chan);
+    )
+}
+
 uhd_error uhd_usrp_set_tx_gain(
     uhd_usrp_handle h,
     double gain,
