@@ -9,10 +9,10 @@
 #define INCLUDED_X300_ADC_CTRL_HPP
 
 #include <uhd/types/serial.hpp>
+#include <uhd/utils/noncopyable.hpp>
 #include <boost/shared_ptr.hpp>
-#include <boost/utility.hpp>
 
-class x300_adc_ctrl : boost::noncopyable
+class x300_adc_ctrl : uhd::noncopyable
 {
 public:
     typedef boost::shared_ptr<x300_adc_ctrl> sptr;
@@ -27,9 +27,10 @@ public:
      */
     static sptr make(uhd::spi_iface::sptr iface, const size_t slaveno);
 
-    virtual double set_gain(const double &) = 0;
+    virtual double set_gain(const double&) = 0;
 
-    virtual void set_test_word(const std::string &patterna, const std::string &patternb, const uint32_t = 0) = 0;
+    virtual void set_test_word(
+        const std::string& patterna, const std::string& patternb, const uint32_t = 0) = 0;
 
     virtual void reset(void) = 0;
 };
