@@ -8,41 +8,41 @@
 #ifndef INCLUDED_X300_DBOARD_IFACE_HPP
 #define INCLUDED_X300_DBOARD_IFACE_HPP
 
-#include "x300_clock_ctrl.hpp"
-#include <uhdlib/usrp/cores/spi_core_3000.hpp>
-#include <uhdlib/usrp/cores/i2c_core_100_wb32.hpp>
-#include <uhdlib/usrp/cores/gpio_atr_3000.hpp>
-#include <uhdlib/usrp/cores/rx_frontend_core_3000.hpp>
-#include "ad7922_regs.hpp" //aux adc
 #include "ad5623_regs.hpp" //aux dac
-#include <uhd/usrp/dboard_iface.hpp>
+#include "ad7922_regs.hpp" //aux adc
+#include "x300_clock_ctrl.hpp"
 #include <uhd/types/dict.hpp>
+#include <uhd/usrp/dboard_iface.hpp>
+#include <uhdlib/usrp/cores/gpio_atr_3000.hpp>
+#include <uhdlib/usrp/cores/i2c_core_100_wb32.hpp>
+#include <uhdlib/usrp/cores/rx_frontend_core_3000.hpp>
+#include <uhdlib/usrp/cores/spi_core_3000.hpp>
 
 struct x300_dboard_iface_config_t
 {
     uhd::usrp::gpio_atr::db_gpio_atr_3000::sptr gpio;
-    spi_core_3000::sptr                         spi;
-    size_t                                      rx_spi_slaveno;
-    size_t                                      tx_spi_slaveno;
-    uhd::i2c_iface::sptr                        i2c;
-    x300_clock_ctrl::sptr                       clock;
-    x300_clock_which_t                          which_rx_clk;
-    x300_clock_which_t                          which_tx_clk;
-    uint8_t                              dboard_slot;
-    uhd::timed_wb_iface::sptr                   cmd_time_ctrl;
+    spi_core_3000::sptr spi;
+    size_t rx_spi_slaveno;
+    size_t tx_spi_slaveno;
+    uhd::i2c_iface::sptr i2c;
+    x300_clock_ctrl::sptr clock;
+    x300_clock_which_t which_rx_clk;
+    x300_clock_which_t which_tx_clk;
+    uint8_t dboard_slot;
+    uhd::timed_wb_iface::sptr cmd_time_ctrl;
 };
 
 class x300_dboard_iface : public uhd::usrp::dboard_iface
 {
 public:
-    x300_dboard_iface(const x300_dboard_iface_config_t &config);
+    x300_dboard_iface(const x300_dboard_iface_config_t& config);
     ~x300_dboard_iface(void);
 
     inline special_props_t get_special_props(void)
     {
         special_props_t props;
         props.soft_clock_divider = false;
-        props.mangle_i2c_addrs = (_config.dboard_slot == 1);
+        props.mangle_i2c_addrs   = (_config.dboard_slot == 1);
         return props;
     }
 
@@ -51,7 +51,8 @@ public:
 
     void set_pin_ctrl(unit_t unit, uint32_t value, uint32_t mask = 0xffffffff);
     uint32_t get_pin_ctrl(unit_t unit);
-    void set_atr_reg(unit_t unit, atr_reg_t reg, uint32_t value, uint32_t mask = 0xffffffff);
+    void set_atr_reg(
+        unit_t unit, atr_reg_t reg, uint32_t value, uint32_t mask = 0xffffffff);
     uint32_t get_atr_reg(unit_t unit, atr_reg_t reg);
     void set_gpio_ddr(unit_t unit, uint32_t value, uint32_t mask = 0xffffffff);
     uint32_t get_gpio_ddr(unit_t unit);
@@ -62,7 +63,7 @@ public:
     void set_command_time(const uhd::time_spec_t& t);
     uhd::time_spec_t get_command_time(void);
 
-    void write_i2c(uint16_t, const uhd::byte_vector_t &);
+    void write_i2c(uint16_t, const uhd::byte_vector_t&);
     uhd::byte_vector_t read_i2c(uint16_t, size_t);
 
     void set_clock_rate(unit_t, double);
@@ -72,21 +73,12 @@ public:
     double get_codec_rate(unit_t);
 
     void write_spi(
-        unit_t unit,
-        const uhd::spi_config_t &config,
-        uint32_t data,
-        size_t num_bits
-    );
+        unit_t unit, const uhd::spi_config_t& config, uint32_t data, size_t num_bits);
 
     uint32_t read_write_spi(
-        unit_t unit,
-        const uhd::spi_config_t &config,
-        uint32_t data,
-        size_t num_bits
-    );
+        unit_t unit, const uhd::spi_config_t& config, uint32_t data, size_t num_bits);
     void set_fe_connection(
-        unit_t unit,  const std::string& name,
-        const uhd::usrp::fe_connection_t& fe_conn);
+        unit_t unit, const std::string& name, const uhd::usrp::fe_connection_t& fe_conn);
 
     // X300 can set the FE connection on the RX side
     bool has_set_fe_connection(const unit_t unit) override
@@ -94,9 +86,7 @@ public:
         return unit == UNIT_RX;
     }
 
-    void add_rx_fe(
-        const std::string& fe_name,
-        rx_frontend_core_3000::sptr fe_core);
+    void add_rx_fe(const std::string& fe_name, rx_frontend_core_3000::sptr fe_core);
 
 private:
     const x300_dboard_iface_config_t _config;
@@ -107,5 +97,4 @@ private:
 };
 
 
-
 #endif /* INCLUDED_X300_DBOARD_IFACE_HPP */
