@@ -18,8 +18,9 @@ SPIEdge = lib.types.spi_edge
 SPIConfig = lib.types.spi_config
 RXMetadataErrorCode = lib.types.rx_metadata_error_code
 Range = lib.types.range
-RangeVector = lib.types.range_vector
-MetaRange = lib.types.meta_range
+MetaRange = lib.types.meta_range_t
+GainRange = lib.types.meta_range_t
+FreqRange = lib.types.meta_range_t
 RXMetadata = lib.types.rx_metadata
 TXMetadata = lib.types.tx_metadata
 TXAsyncMetadata = lib.types.async_metadata
