@@ -5,15 +5,16 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 //
 
-#include <boost/test/unit_test.hpp>
-#include <uhd/types/mac_addr.hpp>
 #include <uhd/types/device_addr.hpp>
+#include <uhd/types/mac_addr.hpp>
 #include <uhd/usrp/dboard_id.hpp>
 #include <boost/assign/list_of.hpp>
+#include <boost/test/unit_test.hpp>
 #include <algorithm>
 #include <iostream>
 
-BOOST_AUTO_TEST_CASE(test_mac_addr){
+BOOST_AUTO_TEST_CASE(test_mac_addr)
+{
     std::cout << "Testing mac addr..." << std::endl;
     const std::string mac_addr_str("00:01:23:45:67:89");
     uhd::mac_addr_t mac_addr = uhd::mac_addr_t::from_string(mac_addr_str);
@@ -22,39 +23,40 @@ BOOST_AUTO_TEST_CASE(test_mac_addr){
     BOOST_CHECK_EQUAL(mac_addr_str, mac_addr.to_string());
 }
 
-BOOST_AUTO_TEST_CASE(test_device_addr){
+BOOST_AUTO_TEST_CASE(test_device_addr)
+{
     std::cout << "Testing device addr..." << std::endl;
 
-    //load the device address with something
+    // load the device address with something
     uhd::device_addr_t dev_addr;
     dev_addr["key1"] = "val1";
     dev_addr["key1"] = "val1";
     dev_addr["key3"] = "";
 
-    //convert to and from args string
+    // convert to and from args string
     std::cout << "Pretty Print: " << std::endl << dev_addr.to_pp_string();
     std::string args_str = dev_addr.to_string();
     std::cout << "Args String: " << args_str << std::endl;
     uhd::device_addr_t new_dev_addr(args_str);
 
-    //they should be the same size
+    // they should be the same size
     BOOST_REQUIRE_EQUAL(dev_addr.size(), new_dev_addr.size());
 
-    //the keys should match
+    // the keys should match
     std::vector<std::string> old_dev_addr_keys = dev_addr.keys();
     std::vector<std::string> new_dev_addr_keys = new_dev_addr.keys();
-    BOOST_CHECK_EQUAL_COLLECTIONS(
-        old_dev_addr_keys.begin(), old_dev_addr_keys.end(),
-        new_dev_addr_keys.begin(), new_dev_addr_keys.end()
-    );
+    BOOST_CHECK_EQUAL_COLLECTIONS(old_dev_addr_keys.begin(),
+        old_dev_addr_keys.end(),
+        new_dev_addr_keys.begin(),
+        new_dev_addr_keys.end());
 
-    //the vals should match
+    // the vals should match
     std::vector<std::string> old_dev_addr_vals = dev_addr.vals();
     std::vector<std::string> new_dev_addr_vals = new_dev_addr.vals();
-    BOOST_CHECK_EQUAL_COLLECTIONS(
-        old_dev_addr_vals.begin(), old_dev_addr_vals.end(),
-        new_dev_addr_vals.begin(), new_dev_addr_vals.end()
-    );
+    BOOST_CHECK_EQUAL_COLLECTIONS(old_dev_addr_vals.begin(),
+        old_dev_addr_vals.end(),
+        new_dev_addr_vals.begin(),
+        new_dev_addr_vals.end());
 
     uhd::device_addr_t dev_addr_lhs1("key1=val1,key2=val2");
     dev_addr_lhs1.update(uhd::device_addr_t("key2=val2x,key3=val3"), false);
@@ -64,7 +66,8 @@ BOOST_AUTO_TEST_CASE(test_device_addr){
     std::cout << "Merged: " << dev_addr_lhs1.to_string() << std::endl;
 }
 
-BOOST_AUTO_TEST_CASE(test_dboard_id){
+BOOST_AUTO_TEST_CASE(test_dboard_id)
+{
     std::cout << "Testing dboard id..." << std::endl;
 
     using namespace uhd::usrp;
@@ -76,7 +79,8 @@ BOOST_AUTO_TEST_CASE(test_dboard_id){
     std::cout << "Pretty Print: " << std::endl << dboard_id_t::none().to_pp_string();
 }
 
-BOOST_AUTO_TEST_CASE(test_map_device_addr){
+BOOST_AUTO_TEST_CASE(test_map_device_addr)
+{
     std::map<std::string, std::string> dev_addr_map;
     dev_addr_map["key1"] = "val1";
     dev_addr_map["key2"] = "val2";
