@@ -37,11 +37,24 @@ from rx_samples_to_file_test import rx_samples_to_file_test
 rx_samples_to_file_test.tests = {
     'default': {
         'duration': 1,
-        'subdev': 'A:A',
+        'subdev': 'A:0',
         'rate': 5e6,
     },
 }
 
+from tx_waveforms_test import uhd_tx_waveforms_test
+uhd_tx_waveforms_test.tests = {
+    'chan0': {
+        'chan': '0',
+    },
+    'chan1': {
+        'chan': '0',
+    },
+    'both_chans': {
+        'chan': '0,1',
+    },
+}
+
 from tx_bursts_test import uhd_tx_bursts_test
 from test_pps_test import uhd_test_pps_test
 
