@@ -15,23 +15,28 @@
 #define MAKE_NODE(name) test_node::sptr name(new test_node(#name));
 
 // Smallest possible test class
-class test_node : virtual public uhd::rfnoc::sink_node_ctrl, virtual public uhd::rfnoc::source_node_ctrl
+class test_node : virtual public uhd::rfnoc::sink_node_ctrl,
+                  virtual public uhd::rfnoc::source_node_ctrl
 {
 public:
     typedef boost::shared_ptr<test_node> sptr;
 
-    test_node(const std::string &test_id) : _test_id(test_id) {};
+    test_node(const std::string& test_id) : _test_id(test_id){};
 
-    void issue_stream_cmd(const uhd::stream_cmd_t &, const size_t) {/* nop */};
+    void issue_stream_cmd(const uhd::stream_cmd_t&, const size_t){/* nop */};
 
-    std::string get_test_id() const { return _test_id; };
+    std::string get_test_id() const
+    {
+        return _test_id;
+    };
 
 private:
     const std::string _test_id;
 
 }; /* class test_node */
 
-void connect_nodes(uhd::rfnoc::source_node_ctrl::sptr A, uhd::rfnoc::sink_node_ctrl::sptr B)
+void connect_nodes(
+    uhd::rfnoc::source_node_ctrl::sptr A, uhd::rfnoc::sink_node_ctrl::sptr B)
 {
     const size_t actual_src_port = A->connect_downstream(B);
     const size_t actual_dst_port = B->connect_upstream(A);
@@ -40,4 +45,3 @@ void connect_nodes(uhd::rfnoc::source_node_ctrl::sptr A, uhd::rfnoc::sink_node_c
 }
 
 #endif /* INCLUDED_TEST_GRAPH_HPP */
-// vim: sw=4 et:
