@@ -131,6 +131,12 @@ class PeriphManagerBase(object):
     # specific implementation. Each PeriphManagerBase-derived class should list
     # information required to update the component, like a callback function
     updateable_components = {}
+    # The RPC server checks this value to determine if it needs to clear
+    # the RPC method registry. This is typically to remove stale references
+    # to RPC methods caused by removal of overlay on unclaim() by peripheral
+    # manager. Additionally the RPC server will re-register all methods on
+    # a claim(). Override and set to True in the derived class if desired.
+    clear_rpc_method_registry_on_unclaim = False
 
     @staticmethod
     def generate_device_info(eeprom_md, mboard_info, dboard_infos):
@@ -169,11 +175,12 @@ class PeriphManagerBase(object):
     ###########################################################################
     # Device initialization (at MPM startup)
     ###########################################################################
-    def __init__(self, args):
+    def __init__(self):
         # Note: args is a dictionary.
         assert len(self.pids) > 0
         assert self.mboard_eeprom_magic is not None
         self.dboards = []
+        self._default_args = ""
         # Set up logging
         self.log = get_logger('PeriphManager')
         self.claimed = False
@@ -183,36 +190,48 @@ class PeriphManagerBase(object):
             self.mboard_info = self._get_mboard_info(self._eeprom_head)
             self.log.info("Device serial number: {}"
                           .format(self.mboard_info.get('serial', 'n/a')))
-            dboard_infos = self._get_dboard_eeprom_info()
+            self.dboard_infos = self._get_dboard_eeprom_info()
             self.device_info = \
                     self.generate_device_info(
                         self._eeprom_head,
                         self.mboard_info,
-                        dboard_infos
+                        self.dboard_infos
                     )
-            self._default_args = self._update_default_args(args)
-            self.log.debug("Using default args: {}".format(self._default_args))
-            self._init_mboard_overlays()
-            override_db_pids_str = self._default_args.get('override_db_pids')
-            if override_db_pids_str:
-                override_db_pids = [
-                    int(x, 0) for x in override_db_pids_str.split(",")
-                ]
-            else:
-                override_db_pids = []
-            self._init_dboards(
-                dboard_infos,
-                override_db_pids,
-                self._default_args
-            )
-            self._device_initialized = True
-            self._initialization_status = "No errors."
         except Exception as ex:
             self.log.error("Failed to initialize device: %s", str(ex))
             self._device_initialized = False
             self._initialization_status = str(ex)
         super(PeriphManagerBase, self).__init__()
 
+    def overlay_apply(self):
+        """
+        Apply FPGA overlay
+        """
+        self._init_mboard_overlays()
+
+    def init_dboards(self, args):
+        """
+        Run full initialization of daughter boards if they exist.
+        Use 'override_db_pids' args to overwrite number of dboards that get
+        initialized.
+        """
+        self._default_args = self._update_default_args(args)
+        self.log.debug("Using default args: {}".format(self._default_args))
+        override_db_pids_str = self._default_args.get('override_db_pids')
+        if override_db_pids_str:
+            override_db_pids = [
+                int(x, 0) for x in override_db_pids_str.split(",")
+            ]
+        else:
+            override_db_pids = []
+        self._init_dboards(
+            self.dboard_infos,
+            override_db_pids,
+            self._default_args
+        )
+        self._device_initialized = True
+        self._initialization_status = "No errors."
+
     def _read_mboard_eeprom(self):
         """
         Read out mboard EEPROM.
@@ -225,6 +244,9 @@ class PeriphManagerBase(object):
         if len(self.mboard_eeprom_addr):
             self.log.trace("Reading EEPROM from address `{}'..."
                            .format(self.mboard_eeprom_addr))
+            if (not get_eeprom_paths(self.mboard_eeprom_addr)):
+                raise RuntimeError("No EEPROM found at address `{}'"
+                    .format(self.mboard_eeprom_addr))
             (eeprom_head, eeprom_rawdata) = eeprom.read_eeprom(
                 get_eeprom_paths(self.mboard_eeprom_addr)[0],
                 self.mboard_eeprom_offset,
@@ -269,22 +291,32 @@ class PeriphManagerBase(object):
                     )
                 )
                 raise RuntimeError("Invalid PID found in EEPROM.")
-        if 'rev' in eeprom_head:
-            try:
-                rev_numeric = int(eeprom_head.get('rev'))
-            except (ValueError, TypeError):
-                raise RuntimeError(
-                    "Invalid revision info read from EEPROM!"
-                )
-            if self.mboard_max_rev is not None \
-                    and rev_numeric > self.mboard_max_rev:
-                raise RuntimeError(
-                    "Device has revision `{}', but max supported " \
-                    "revision is `{}'".format(
-                        rev_numeric, self.mboard_max_rev
-                    ))
+        # The rev_compat is either directly stored in the EEPROM, or we fall
+        # back to the the rev itself (because every rev is compatible with
+        # itself).
+        rev_compat = \
+            eeprom_head.get('rev_compat', eeprom_head.get('rev'))
+        try:
+            rev_compat = int(rev_compat)
+        except (ValueError, TypeError):
+            raise RuntimeError(
+                "Invalid revision compat info read from EEPROM!"
+            )
+        # We check if this software is actually compatible with the hardware.
+        # In order for the software to be able to understand the hardware, the
+        # rev_compat value (stored on the EEPROM) must be smaller or equal to
+        # the value stored in the software itself.
+        if self.mboard_max_rev is None:
+            self.log.warning("Skipping HW/SW compatibility check!")
         else:
-            raise RuntimeError("No revision found in EEPROM.")
+            if rev_compat > self.mboard_max_rev:
+                raise RuntimeError(
+                    "Software is maximally compatible with revision `{}', but "
+                    "the hardware has revision `{}' and is minimally compatible "
+                    "with hardware revision `{}'. Please upgrade your version of"
+                    "MPM in order to use this device."
+                    .format(self.mboard_max_rev, mboard_info['rev'], rev_compat)
+                )
         return mboard_info
 
     def _get_dboard_eeprom_info(self):
