@@ -32,7 +32,7 @@ E320_DEFAULT_CLOCK_SOURCE = 'internal'
 E320_DEFAULT_TIME_SOURCE = 'internal'
 E320_DEFAULT_ENABLE_GPS = True
 E320_DEFAULT_ENABLE_FPGPIO = True
-E320_FPGA_COMPAT = (3, 0)
+E320_FPGA_COMPAT = (3, 1)
 E320_MONITOR_THREAD_INTERVAL = 1.0 # seconds
 E320_DBOARD_SLOT_IDX = 0
 
@@ -78,7 +78,7 @@ class e320(ZynqComponents, PeriphManagerBase):
     mboard_info = {"type": "e3xx",
                    "product": "e320"
                   }
-    mboard_max_rev = 2  # RevB
+    mboard_max_rev = 4  # rev E
     mboard_sensor_callback_map = {
         'ref_locked': 'get_ref_lock_sensor',
         'gps_locked': 'get_gps_lock_sensor',
@@ -90,7 +90,6 @@ class e320(ZynqComponents, PeriphManagerBase):
         'temp_main_power' : 'get_main_power_temp_sensor',
     }
     max_num_dboards = 1
-    crossbar_base_port = 2  # It's 2 because 0,1 are SFP,DMA
 
     # We're on a Zynq target, so the following two come from the Zynq standard
     # device tree overlay (tree/arch/arm/boot/dts/zynq-7000.dtsi)
@@ -129,7 +128,9 @@ class e320(ZynqComponents, PeriphManagerBase):
     # Ctor and device initialization tasks
     ###########################################################################
     def __init__(self, args):
-        super(e320, self).__init__(args)
+        super(e320, self).__init__()
+        self.overlay_apply()
+        self.init_dboards(args)
         if not self._device_initialized:
             # Don't try and figure out what's going on. Just give up.
             return
@@ -265,6 +266,7 @@ class e320(ZynqComponents, PeriphManagerBase):
         self.mboard_regs_control.get_build_timestamp()
         self._check_fpga_compat()
         self._update_fpga_type()
+        self.crossbar_base_port = self.mboard_regs_control.get_xbar_baseport()
         # Init peripherals
         self.enable_gps(
             enable=str2bool(
@@ -283,7 +285,7 @@ class e320(ZynqComponents, PeriphManagerBase):
         self._init_gps_sensors()
         # Init CHDR transports
         self._xport_mgrs = {
-            'udp': E320XportMgrUDP(self.log.getChild('UDP')),
+            'udp': E320XportMgrUDP(self.log.getChild('UDP'), args),
             'liberio': E320XportMgrLiberio(self.log.getChild('liberio')),
         }
         # Spawn status monitoring thread
@@ -439,6 +441,8 @@ class e320(ZynqComponents, PeriphManagerBase):
         device_info.update({
             'fpga_version': "{}.{}".format(
                 *self.mboard_regs_control.get_compat_number()),
+            'fpga_version_hash': "{:x}.{}".format(
+                *self.mboard_regs_control.get_git_hash()),
             'fpga': self.updateable_components.get('fpga', {}).get('type',""),
         })
         return device_info
