@@ -2,20 +2,9 @@
  * Dissector for UHD CVITA (CHDR) packets
  *
  * Copyright 2010-2014 Ettus Research LLC
+ * Copyright 2019 Ettus Research, a National Instruments brand
  *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 #include "config.h"
@@ -41,6 +30,9 @@ static int hf_chdr_type = -1;
 static int hf_chdr_has_time = -1;
 static int hf_chdr_eob = -1;
 static int hf_chdr_error = -1;
+static int hf_chdr_fc_ack = -1;
+static int hf_chdr_fc_pktcount = -1;
+static int hf_chdr_fc_bytecount = -1;
 static int hf_chdr_sequence = -1;
 static int hf_chdr_packet_size = -1;
 static int hf_chdr_stream_id = -1;
@@ -53,6 +45,7 @@ static int hf_chdr_dst_blockport = -1;
 static int hf_chdr_timestamp = -1;
 static int hf_chdr_payload = -1;
 static int hf_chdr_ext_response = -1;
+static int hf_chdr_ext_fc = -1;
 static int hf_chdr_ext_status_code = -1;
 static int hf_chdr_ext_seq_num = -1;
 static int hf_chdr_cmd = -1;
@@ -63,6 +56,7 @@ static const value_string CHDR_PACKET_TYPES[] = {
     { 0, "Data" },
     { 1, "Data (End-of-Burst)" },
     { 4, "Flow Control" },
+    { 5, "Flow Control (ACK)" },
     { 8, "Command" },
     { 12, "Response" },
     { 13, "Error Response" },
@@ -72,6 +66,7 @@ static const value_string CHDR_PACKET_TYPES_SHORT[] = {
     { 0, "data" },
     { 1, "data" },
     { 4, "fc" },
+    { 5, "fc" },
     { 8, "cmd" },
     { 12, "resp" },
     { 13, "resp" },
@@ -87,12 +82,20 @@ static gint ett_chdr = -1;
 static gint ett_chdr_header = -1;
 static gint ett_chdr_id = -1;
 static gint ett_chdr_response = -1;
+static gint ett_chdr_fc = -1;
 static gint ett_chdr_cmd = -1;
 
 /* Forward-declare the dissector functions */
 void proto_register_chdr(void);
 void proto_reg_handoff_chdr(void);
+
+#if VERSION_MAJOR == 1
 static void dissect_chdr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
+#elif (VERSION_MAJOR == 2) || (VERSION_MAJOR == 3)
+static int dissect_chdr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data);
+#else
+#error Wireshark version not found or not compatible
+#endif
 
 /* heuristic dissector call. Will always return. */
 static gboolean heur_dissect_chdr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* whatislove)
@@ -101,7 +104,11 @@ static gboolean heur_dissect_chdr(tvbuff_t *tvb, packet_info *pinfo, proto_tree
         printf(LOG_HEADER"heuristic dissector always returns true!\n");
         heur_warning_printed++;
     }
+#if VERSION_MAJOR == 1
     dissect_chdr(tvb, pinfo, tree);
+#elif (VERSION_MAJOR == 2) || (VERSION_MAJOR == 3)
+    dissect_chdr(tvb, pinfo, tree, whatislove);
+#endif
     return (TRUE);
 }
 
@@ -145,7 +152,11 @@ static unsigned long long get_timestamp(guint8 *bytes, gint len)
 }
 
 /* The dissector itself */
+#if VERSION_MAJOR == 1
 static void dissect_chdr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
+#elif (VERSION_MAJOR == 2) || (VERSION_MAJOR == 3)
+static int dissect_chdr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
+#endif
 {
     // Here are all the variables
     proto_item *item;
@@ -158,6 +169,8 @@ static void dissect_chdr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     proto_tree *response_tree;
     proto_item *cmd_item;
     proto_tree *cmd_tree;
+    proto_item *fc_item;
+    proto_tree *fc_tree;
     gint len;
 
     gint flag_offset;
@@ -170,6 +183,7 @@ static void dissect_chdr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     gboolean flag_is_resp = 0;
     gboolean flag_is_eob = 0;
     gboolean flag_is_error = 0;
+    gboolean flag_is_fcack = 0;
     uint64_t timestamp;
     gboolean is_network;
     gint endianness;
@@ -213,6 +227,7 @@ static void dissect_chdr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             flag_is_resp = (pkt_type == 3);
             flag_is_eob = flag_is_data && (hdr_bits & 0x1);
             flag_is_error = flag_is_resp && (hdr_bits & 0x1);
+            flag_is_fcack = flag_is_fc && (hdr_bits & 0x1);
             flag_has_time = hdr_bits & 0x2;
             if (flag_has_time) {
                 header_size += 8; // 64-bit timestamp.
@@ -246,6 +261,9 @@ static void dissect_chdr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 proto_tree_add_boolean(header_tree, hf_chdr_error, tvb, flag_offset, 1, flag_is_error);
                 /*proto_tree_add_boolean(header_tree, hf_chdr_error, tvb, flag_offset, 1, true);*/
             }
+            if (flag_is_fc) {
+                proto_tree_add_boolean(header_tree, hf_chdr_fc_ack, tvb, flag_offset, 1, flag_is_fcack);
+            }
 
             /* These lines add sequence, packet_size and stream ID */
             proto_tree_add_item(chdr_tree, hf_chdr_sequence, tvb, (is_network ? 0:2), 2, endianness);
@@ -306,12 +324,20 @@ static void dissect_chdr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                     proto_tree_add_item(response_tree, hf_chdr_ext_status_code, tvb, header_size, 4, endianness);
                     /* This will show the 12-bits of sequence ID in the last 2 bytes */
                     proto_tree_add_item(response_tree, hf_chdr_ext_seq_num, tvb, (header_size + 4 + (is_network ? 2 : 0)), 2, endianness);
+                } else if (flag_is_fc) {
+                    fc_item = proto_tree_add_item(chdr_tree, hf_chdr_ext_fc, tvb, header_size, 8, endianness);
+                    fc_tree = proto_item_add_subtree(fc_item, ett_chdr_fc);
+                    proto_tree_add_item(fc_tree, hf_chdr_fc_pktcount,  tvb, header_size,     4, endianness);
+                    proto_tree_add_item(fc_tree, hf_chdr_fc_bytecount, tvb, header_size + 4, 4, endianness);
                 } else if (show_raw_payload) {
                     proto_tree_add_item(chdr_tree, hf_chdr_payload, tvb, header_size, -1, ENC_NA);
                 }
             }
         }
     }
+#if (VERSION_MAJOR == 2) || (VERSION_MAJOR == 3)
+  return (tvb_captured_length(tvb));
+#endif
 }
 
 void proto_register_chdr(void)
@@ -331,22 +357,46 @@ void proto_register_chdr(void)
         },
         { &hf_chdr_has_time,
             { "Has time", "chdr.hdr.has_time",
-                FT_BOOLEAN, BASE_NONE,
+                FT_BOOLEAN, 1,
                 NULL, 0x20,
                 NULL, HFILL }
         },
         { &hf_chdr_eob,
             { "End Of Burst", "chdr.hdr.eob",
-                FT_BOOLEAN, BASE_NONE,
+                FT_BOOLEAN, 1,
                 NULL, 0x10,
                 NULL, HFILL }
         },
         { &hf_chdr_error,
             { "Error Flag", "chdr.hdr.error",
-                FT_BOOLEAN, BASE_NONE,
+                FT_BOOLEAN, 1,
                 NULL, 0x10,
                 NULL, HFILL }
         },
+        { &hf_chdr_fc_ack,
+            { "FC ACK Flag", "chdr.hdr.fc_ack",
+                FT_BOOLEAN, 1,
+                NULL, 0x10,
+                NULL, HFILL }
+        },
+        { &hf_chdr_ext_fc,
+            { "Flow Control", "chdr.fc",
+                FT_BYTES, BASE_NONE,
+                NULL, 0x0,
+                NULL, HFILL }
+        },
+	{ &hf_chdr_fc_bytecount,
+	    { "FC Byte Count", "chdr.hdr.fc.byte_count",
+		FT_UINT32, BASE_DEC,
+		NULL, 0x0,
+		NULL, HFILL }
+	},
+	{ &hf_chdr_fc_pktcount,
+	    { "FC Packet Count", "chdr.hdr.fc.pkt_count",
+		FT_UINT32, BASE_DEC,
+		NULL, 0x0,
+		NULL, HFILL }
+	},
         { &hf_chdr_sequence,
             { "Sequence ID", "chdr.seq",
                 FT_UINT16, BASE_DEC,
@@ -457,6 +507,7 @@ void proto_register_chdr(void)
         &ett_chdr_header,
         &ett_chdr_id,
         &ett_chdr_response,
+        &ett_chdr_fc,
         &ett_chdr_cmd
     };
 
@@ -472,10 +523,8 @@ void proto_reg_handoff_chdr(void)
     /* register heuristic dissector for use with USB */
 #if VERSION_MAJOR == 1
     heur_dissector_add("usb.bulk", heur_dissect_chdr, proto_chdr);
-#elif VERSION_MAJOR == 2
+#elif (VERSION_MAJOR == 2) || (VERSION_MAJOR == 3)
     heur_dissector_add("usb.bulk", heur_dissect_chdr, "USB dissector", "usb_bulk", proto_chdr, HEURISTIC_ENABLE);
-#else
-#error Wireshark version not found or not compatible
 #endif
     /* register dissector for UDP packets */
     static dissector_handle_t chdr_handle;
